"""
Inspired by an xkcd comic (https://xkcd.com/936/), I wrote this random password generator.

Instead of simply using random sets of words, it groups words into nouns (N), adjectives (A),
verbse (V), modifieres (verbs + adjectives), digits (D), and punctuation (P). Based on a formula
described by the precedeeing letter codes (e.g. NVN which means Noun Verb Noun), you can generate
a random password and calculate its entropy (number of possible passwords according to the formula).
"""
nouns = [
  'abdomen',
  'ability',
  'abode',
  'abraham',
  'absence',
  'abuse',
  'abyss',
  'academic',
  'academy',
  'access',
  'accident',
  'account',
  'accounts',
  'accuracy',
  'accused',
  'ace',
  'acne',
  'acolyte',
  'acres',
  'act',
  'acting',
  'action',
  'actions',
  'activity',
  'acton',
  'actor',
  'actors',
  'actress',
  'adam',
  'adamant',
  'addition',
  'ade',
  'adept',
  'adieu',
  'admiral',
  'adults',
  'advice',
  'advocate',
  'aerosol',
  'affair',
  'affairs',
  'affect',
  'affects',
  'africa',
  'african',
  'agape',
  'age',
  'agency',
  'agenda',
  'agent',
  'agents',
  'ages',
  'agility',
  'agnostic',
  'agony',
  'ahab',
  'aide',
  'air',
  'aircraft',
  'airlock',
  'airplane',
  'airport',
  'airs',
  'aisle',
  'aisles',
  'alacrity',
  'alarm',
  'alarms',
  'album',
  'alcohol',
  'alcove',
  'alcoves',
  'ale',
  'alerts',
  'algae',
  'aliens',
  'alley',
  'alleys',
  'alleyway',
  'alliance',
  'alloy',
  'almighty',
  'almond',
  'almonds',
  'alpha',
  'alphabet',
  'altar',
  'altitude',
  'alto',
  'amateur',
  'amber',
  'ambition',
  'amends',
  'america',
  'american',
  'ames',
  'amnesia',
  'amulet',
  'analysis',
  'analyst',
  'ancestor',
  'ancestry',
  'anchor',
  'ancients',
  'angel',
  'angelic',
  'angels',
  'angle',
  'angled',
  'angles',
  'angling',
  'anglo',
  'anguish',
  'animal',
  'animals',
  'anking',
  'ankle',
  'ankles',
  'anna',
  'annals',
  'anne',
  'anomaly',
  'answer',
  'answers',
  'ant',
  'antenna',
  'antennae',
  'anti',
  'antics',
  'ants',
  'anvil',
  'anxiety',
  'anybody',
  'anyone',
  'anything',
  'apology',
  'apostasy',
  'apostles',
  'appeal',
  'appetite',
  'applause',
  'apple',
  'apples',
  'approval',
  'april',
  'apron',
  'aprons',
  'aptitude',
  'arabian',
  'arc',
  'arcade',
  'arch',
  'arches',
  'archive',
  'archives',
  'archway',
  'arcs',
  'area',
  'areas',
  'arena',
  'ares',
  'argument',
  'arm',
  'armada',
  'armchair',
  'armful',
  'armies',
  'armor',
  'armory',
  'armpit',
  'armpits',
  'arms',
  'army',
  'aroma',
  'arrears',
  'arrival',
  'arrivals',
  'arrives',
  'arrow',
  'arrows',
  'arsenal',
  'arteries',
  'arthur',
  'article',
  'articles',
  'artifact',
  'artisans',
  'artist',
  'artists',
  'arts',
  'artwork',
  'ascent',
  'ash',
  'ashes',
  'ashtray',
  'aspect',
  'aspects',
  'asphalt',
  'ass',
  'assassin',
  'assault',
  'assaults',
  'assembly',
  'asset',
  'assets',
  'asshole',
  'asteroid',
  'ate',
  'athlete',
  'atlanta',
  'atom',
  'atoms',
  'attic',
  'attitude',
  'attorney',
  'auction',
  'audacity',
  'audience',
  'audit',
  'auditory',
  'august',
  'augustus',
  'aunt',
  'auntie',
  'aunts',
  'aura',
  'austen',
  'author',
  'authors',
  'auto',
  'autumn',
  'autumnal',
  'avarice',
  'ave',
  'avenue',
  'avenues',
  'average',
  'aversion',
  'awe',
  'awnings',
  'axe',
  'axes',
  'axle',
  'axles',
  'azure',
  'babe',
  'baby',
  'bachelor',
  'back',
  'backbone',
  'backdrop',
  'backed',
  'backing',
  'backpack',
  'backs',
  'backside',
  'backup',
  'backyard',
  'bacon',
  'badge',
  'bag',
  'baggage',
  'bags',
  'bail',
  'bailiff',
  'baker',
  'balance',
  'balanced',
  'balances',
  'balcony',
  'bales',
  'ball',
  'ballet',
  'balloon',
  'balloons',
  'ballroom',
  'balls',
  'balm',
  'bamboo',
  'band',
  'bandage',
  'bandages',
  'bandit',
  'bandits',
  'bands',
  'bangs',
  'banister',
  'bank',
  'banking',
  'banks',
  'banner',
  'banners',
  'banquet',
  'bar',
  'bargain',
  'barge',
  'barges',
  'baring',
  'baritone',
  'barley',
  'barn',
  'baron',
  'barons',
  'barracks',
  'barrage',
  'barrel',
  'barreled',
  'barrels',
  'barrier',
  'barriers',
  'bars',
  'base',
  'baseball',
  'based',
  'basement',
  'basic',
  'basin',
  'basis',
  'basket',
  'baskets',
  'bass',
  'bastard',
  'bastards',
  'bastion',
  'bat',
  'batch',
  'bath',
  'bathroom',
  'baths',
  'bathtub',
  'batons',
  'battery',
  'batting',
  'battle',
  'battles',
  'bauble',
  'bays',
  'beach',
  'beacon',
  'beacons',
  'bead',
  'beads',
  'beak',
  'beam',
  'beams',
  'beans',
  'bear',
  'beard',
  'bearded',
  'beards',
  'bearer',
  'bearers',
  'bearing',
  'bearings',
  'bears',
  'beast',
  'beasts',
  'beating',
  'beatings',
  'beauties',
  'beauty',
  'bed',
  'bedding',
  'bedlam',
  'bedrock',
  'bedroom',
  'bedrooms',
  'bedside',
  'bedstead',
  'bedtime',
  'bee',
  'beech',
  'beef',
  'beehive',
  'beep',
  'beer',
  'bees',
  'beetle',
  'beetles',
  'beggar',
  'beggars',
  'behalf',
  'behavior',
  'behemoth',
  'behest',
  'beige',
  'being',
  'beings',
  'belgium',
  'belief',
  'beliefs',
  'bell',
  'belle',
  'bellies',
  'bellows',
  'bells',
  'belly',
  'belt',
  'belted',
  'belts',
  'bench',
  'benches',
  'bene',
  'benefit',
  'benefits',
  'benny',
  'bent',
  'berries',
  'berry',
  'berth',
  'bet',
  'beta',
  'beverage',
  'bible',
  'bicep',
  'bicycle',
  'bike',
  'bile',
  'bill',
  'billing',
  'billion',
  'billions',
  'billow',
  'billows',
  'bills',
  'billy',
  'bin',
  'binding',
  'bindings',
  'bio',
  'biology',
  'bird',
  'birdlike',
  'birds',
  'birdsong',
  'birth',
  'birthday',
  'bishop',
  'bit',
  'bitch',
  'bits',
  'blacking',
  'bladder',
  'bladders',
  'blade',
  'blades',
  'blah',
  'blanket',
  'blankets',
  'blast',
  'blasts',
  'blaze',
  'blazers',
  'blessing',
  'blight',
  'blinker',
  'blip',
  'bliss',
  'blisters',
  'blizzard',
  'blob',
  'block',
  'blocks',
  'blood',
  'bloom',
  'blossom',
  'blossoms',
  'blot',
  'blots',
  'blouse',
  'blues',
  'blur',
  'blurs',
  'blush',
  'blushes',
  'blustery',
  'boar',
  'board',
  'boarders',
  'boards',
  'boast',
  'boastful',
  'boasts',
  'boat',
  'boatman',
  'boats',
  'bodice',
  'bodies',
  'body',
  'bolster',
  'bolt',
  'bolts',
  'bomb',
  'bomber',
  'bond',
  'bondage',
  'bonds',
  'bone',
  'boned',
  'bones',
  'bonnet',
  'bonus',
  'booby',
  'book',
  'bookcase',
  'books',
  'boot',
  'booth',
  'boots',
  'border',
  'bordered',
  'borders',
  'boredom',
  'borough',
  'bosom',
  'boss',
  'bosses',
  'boston',
  'bottle',
  'bottles',
  'bottom',
  'bottomed',
  'bottoms',
  'boughs',
  'boulder',
  'boulders',
  'boulogne',
  'boundary',
  'bounds',
  'bounty',
  'bouquet',
  'bout',
  'bouts',
  'bowels',
  'bowing',
  'bowl',
  'bowls',
  'box',
  'boxes',
  'boy',
  'boyish',
  'boys',
  'bra',
  'bracelet',
  'brackets',
  'braiding',
  'brain',
  'brains',
  'brakes',
  'bran',
  'branch',
  'branched',
  'branches',
  'brand',
  'branding',
  'brandy',
  'brass',
  'brat',
  'bravado',
  'bravery',
  'brawn',
  'brazier',
  'breach',
  'bread',
  'breadth',
  'breakers',
  'breast',
  'breasts',
  'breath',
  'breaths',
  'breeches',
  'breeding',
  'breeze',
  'breezes',
  'brevity',
  'brian',
  'bribe',
  'brick',
  'bricks',
  'bride',
  'bridge',
  'bridges',
  'bridle',
  'bridles',
  'brie',
  'briefing',
  'brig',
  'brigade',
  'brim',
  'brink',
  'bristle',
  'bristles',
  'britain',
  'british',
  'broach',
  'brocade',
  'broker',
  'brood',
  'brook',
  'brooks',
  'broom',
  'brooms',
  'broth',
  'brothel',
  'brother',
  'brothers',
  'brow',
  'brownish',
  'brows',
  'brunette',
  'brush',
  'brushes',
  'brussels',
  'bubble',
  'bubbles',
  'buck',
  'bucket',
  'buckets',
  'buckle',
  'buddies',
  'buddy',
  'budge',
  'budget',
  'buds',
  'buff',
  'buffer',
  'buffet',
  'bug',
  'bugs',
  'building',
  'bulk',
  'bulkhead',
  'bull',
  'bullet',
  'bulletin',
  'bullets',
  'bullies',
  'bully',
  'bulwark',
  'bum',
  'bump',
  'bumper',
  'bumps',
  'bun',
  'bunch',
  'bunches',
  'bundle',
  'bundles',
  'bunk',
  'bunker',
  'bunks',
  'buoyancy',
  'burden',
  'burdens',
  'burger',
  'burgundy',
  'burial',
  'burlap',
  'burn',
  'burner',
  'burns',
  'burr',
  'burrow',
  'bus',
  'bush',
  'bushes',
  'business',
  'bust',
  'butcher',
  'butler',
  'butter',
  'buttery',
  'buttocks',
  'button',
  'buttons',
  'bye',
  'byes',
  'bypass',
  'cab',
  'cabal',
  'cabbage',
  'cabin',
  'cabinet',
  'cabinets',
  'cable',
  'cables',
  'cache',
  'cadence',
  'cadet',
  'caesar',
  'caffeine',
  'cage',
  'cages',
  'cake',
  'cakes',
  'calais',
  'calamity',
  'calendar',
  'calf',
  'called',
  'calling',
  'calm',
  'camera',
  'cameras',
  'camp',
  'campaign',
  'campsite',
  'campus',
  'canada',
  'canal',
  'canary',
  'cancer',
  'candies',
  'candle',
  'candles',
  'candor',
  'candy',
  'cane',
  'canister',
  'cannon',
  'canoe',
  'canon',
  'canopy',
  'canvas',
  'canyons',
  'cap',
  'capacity',
  'cape',
  'capital',
  'capri',
  'capsules',
  'captain',
  'captains',
  'captor',
  'captors',
  'capture',
  'car',
  'carapace',
  'caravan',
  'carbon',
  'carcass',
  'cardinal',
  'care',
  'career',
  'careers',
  'cares',
  'cargo',
  'cargoes',
  'carlos',
  'carnage',
  'carnival',
  'carol',
  'carousel',
  'carpet',
  'carpets',
  'carriage',
  'carrier',
  'carrion',
  'carrot',
  'carrots',
  'cars',
  'cart',
  'carton',
  'cartoon',
  'carts',
  'carver',
  'carving',
  'carvings',
  'cascade',
  'case',
  'casement',
  'cases',
  'cash',
  'casing',
  'cask',
  'casket',
  'casks',
  'cassette',
  'caste',
  'casting',
  'castle',
  'casualty',
  'cat',
  'catalyst',
  'category',
  'catholic',
  'cation',
  'cations',
  'cats',
  'cattle',
  'catwalks',
  'cauldron',
  'cause',
  'causes',
  'caution',
  'cavalier',
  'cavalry',
  'cave',
  'cavern',
  'caverns',
  'caves',
  'cavities',
  'cavity',
  'cedar',
  'ceiling',
  'ceilings',
  'cell',
  'cellar',
  'cellars',
  'cells',
  'cement',
  'cemetery',
  'cent',
  'center',
  'centers',
  'century',
  'cer',
  'ceremony',
  'cha',
  'chaff',
  'chagrin',
  'chain',
  'chains',
  'chair',
  'chairs',
  'chaise',
  'chalk',
  'chamber',
  'chambers',
  'champion',
  'chance',
  'chances',
  'channel',
  'channels',
  'chaos',
  'chaotic',
  'chap',
  'chapel',
  'chapter',
  'chapters',
  'char',
  'charcoal',
  'charge',
  'charges',
  'charity',
  'charles',
  'charlie',
  'charm',
  'charms',
  'chart',
  'charter',
  'charts',
  'chase',
  'chasm',
  'chassis',
  'chastity',
  'chateau',
  'cheap',
  'check',
  'checker',
  'checks',
  'cheek',
  'cheeks',
  'cheer',
  'cheese',
  'cherries',
  'cherry',
  'chess',
  'chest',
  'chester',
  'chestnut',
  'chests',
  'chicago',
  'chicken',
  'chickens',
  'child',
  'children',
  'chili',
  'chill',
  'chills',
  'chime',
  'chimes',
  'chimney',
  'chimneys',
  'chin',
  'china',
  'chinese',
  'chip',
  'chips',
  'chit',
  'choice',
  'choices',
  'choir',
  'chops',
  'chord',
  'chores',
  'chorus',
  'chosen',
  'christ',
  'chrome',
  'chunk',
  'chunks',
  'church',
  'churches',
  'chute',
  'cigar',
  'cigars',
  'cinder',
  'cinnamon',
  'circle',
  'circles',
  'circuit',
  'circuits',
  'circus',
  'citadel',
  'cities',
  'citizen',
  'city',
  'civilian',
  'civility',
  'claimant',
  'clamor',
  'clamps',
  'clan',
  'claret',
  'clarity',
  'clasp',
  'clasps',
  'class',
  'classes',
  'classics',
  'clause',
  'claw',
  'clawed',
  'claws',
  'clay',
  'cleaner',
  'cleanup',
  'clearing',
  'cleavage',
  'cleft',
  'clemency',
  'clergy',
  'clerk',
  'clerks',
  'client',
  'clients',
  'cliff',
  'cliffs',
  'climate',
  'climax',
  'climbers',
  'clipping',
  'cloak',
  'cloaks',
  'clock',
  'clocks',
  'clod',
  'clods',
  'clones',
  'closer',
  'closet',
  'closets',
  'closing',
  'closure',
  'cloth',
  'clothing',
  'cloths',
  'clots',
  'cloud',
  'clouds',
  'clown',
  'club',
  'clubs',
  'clue',
  'clues',
  'clump',
  'clumps',
  'cluster',
  'clusters',
  'coach',
  'coachman',
  'coal',
  'coals',
  'coast',
  'coastal',
  'coasts',
  'coat',
  'coated',
  'coating',
  'coats',
  'cobwebs',
  'cock',
  'cockpit',
  'cocktail',
  'cocoon',
  'code',
  'codes',
  'coffee',
  'coffers',
  'coffin',
  'cohort',
  'cohorts',
  'coil',
  'coils',
  'coin',
  'coins',
  'coke',
  'cole',
  'collar',
  'collars',
  'collect',
  'college',
  'colleges',
  'colonel',
  'colonies',
  'colony',
  'color',
  'colorado',
  'coloring',
  'colors',
  'columbia',
  'column',
  'columns',
  'comb',
  'combat',
  'combed',
  'combined',
  'combs',
  'comedy',
  'comers',
  'comet',
  'coming',
  'comment',
  'comments',
  'commerce',
  'commons',
  'company',
  'complex',
  'computer',
  'comrade',
  'comrades',
  'conceit',
  'concept',
  'concepts',
  'concert',
  'conduct',
  'conduits',
  'cone',
  'cones',
  'confines',
  'conflict',
  'congress',
  'conquest',
  'console',
  'consoles',
  'consort',
  'contact',
  'contacts',
  'contempt',
  'context',
  'contour',
  'contours',
  'contract',
  'contrary',
  'convent',
  'converse',
  'cook',
  'cookbook',
  'cookie',
  'cookies',
  'cooks',
  'cooler',
  'cop',
  'cope',
  'copies',
  'copilot',
  'coping',
  'copper',
  'cops',
  'copse',
  'copy',
  'coquette',
  'cor',
  'coral',
  'cord',
  'cords',
  'core',
  'cork',
  'corn',
  'corner',
  'cornered',
  'corners',
  'corps',
  'corpse',
  'corpses',
  'corral',
  'corridor',
  'cost',
  'costs',
  'costume',
  'costumes',
  'cot',
  'cottage',
  'cottages',
  'cotton',
  'council',
  'counsel',
  'counter',
  'counters',
  'countess',
  'country',
  'county',
  'couple',
  'couples',
  'courage',
  'courier',
  'couriers',
  'course',
  'courses',
  'coursing',
  'court',
  'courtesy',
  'courtier',
  'courts',
  'cousin',
  'cousins',
  'coverage',
  'covering',
  'coverlet',
  'cow',
  'coward',
  'cowards',
  'cowling',
  'cows',
  'crab',
  'crabs',
  'cradle',
  'craft',
  'crafts',
  'crags',
  'cramp',
  'cramps',
  'crane',
  'crank',
  'cranny',
  'crate',
  'crater',
  'crates',
  'cravat',
  'craving',
  'crayon',
  'cream',
  'crease',
  'creases',
  'creation',
  'creator',
  'creators',
  'creature',
  'credence',
  'credit',
  'creditor',
  'credits',
  'creed',
  'creek',
  'crescent',
  'crest',
  'cresting',
  'crevice',
  'crevices',
  'crewman',
  'crewmen',
  'crews',
  'cricket',
  'crickets',
  'crime',
  'crimes',
  'crimson',
  'cripple',
  'crisis',
  'critic',
  'crockery',
  'cronies',
  'crop',
  'crops',
  'cross',
  'crosses',
  'crossing',
  'crotch',
  'crow',
  'crowbar',
  'crown',
  'crowned',
  'crowns',
  'crows',
  'cruelty',
  'cruiser',
  'cruisers',
  'crumbs',
  'crusade',
  'crust',
  'crusted',
  'crusts',
  'crutch',
  'crystal',
  'crystals',
  'cube',
  'cubes',
  'cubicle',
  'cubs',
  'cucumber',
  'cue',
  'cues',
  'cuff',
  'cuffs',
  'cult',
  'culture',
  'cultures',
  'cup',
  'cupboard',
  'cupid',
  'cupidity',
  'cupping',
  'cups',
  'cur',
  'curb',
  'cure',
  'curling',
  'currency',
  'currents',
  'curse',
  'curses',
  'curtain',
  'curtains',
  'curtsey',
  'cushion',
  'cushions',
  'custard',
  'custody',
  'custom',
  'customer',
  'customs',
  'cutout',
  'cutter',
  'cutting',
  'cyan',
  'cycle',
  'cycles',
  'cyclops',
  'cylinder',
  'cynicism',
  'dad',
  'daddy',
  'dagger',
  'daggers',
  'dainties',
  'dainty',
  'dais',
  'daisies',
  'daisy',
  'dakota',
  'dale',
  'dam',
  'damage',
  'damages',
  'dame',
  'damp',
  'dan',
  'danger',
  'dangers',
  'daniel',
  'darling',
  'dart',
  'darts',
  'database',
  'date',
  'dates',
  'daughter',
  'david',
  'day',
  'daybreak',
  'daydream',
  'daylight',
  'daytime',
  'deal',
  'dealing',
  'dealings',
  'deals',
  'death',
  'deathbed',
  'deaths',
  'debacle',
  'debate',
  'debris',
  'debt',
  'debts',
  'decade',
  'decades',
  'decanter',
  'deceit',
  'december',
  'decency',
  'decision',
  'deck',
  'decking',
  'decks',
  'decoys',
  'decree',
  'decrees',
  'deed',
  'deeds',
  'deer',
  'default',
  'defense',
  'defenses',
  'defiance',
  'degree',
  'degrees',
  'deity',
  'delay',
  'delays',
  'delicacy',
  'delight',
  'delirium',
  'delivery',
  'dell',
  'delta',
  'delusion',
  'demand',
  'demands',
  'demeanor',
  'demon',
  'demons',
  'den',
  'denial',
  'denials',
  'denizens',
  'dens',
  'density',
  'dentist',
  'depth',
  'depths',
  'derision',
  'des',
  'descent',
  'desert',
  'deserts',
  'designer',
  'desk',
  'desks',
  'despite',
  'dessert',
  'destiny',
  'detail',
  'details',
  'detector',
  'detour',
  'detritus',
  'device',
  'devices',
  'devil',
  'devils',
  'devotion',
  'dew',
  'diagram',
  'diagrams',
  'dial',
  'dialect',
  'dialects',
  'dialogue',
  'dials',
  'diameter',
  'diamond',
  'diamonds',
  'diana',
  'diapers',
  'dice',
  'dick',
  'dickens',
  'diction',
  'diego',
  'diet',
  'digest',
  'digits',
  'dignity',
  'dilemma',
  'dimmer',
  'din',
  'diners',
  'dingo',
  'dinner',
  'dinners',
  'director',
  'dirt',
  'dis',
  'disarray',
  'disaster',
  'discount',
  'disdain',
  'disease',
  'diseases',
  'disgust',
  'dish',
  'dishes',
  'disk',
  'disks',
  'dislike',
  'disposal',
  'distance',
  'distress',
  'district',
  'distrust',
  'ditch',
  'ditches',
  'divan',
  'diver',
  'division',
  'divorce',
  'dna',
  'doc',
  'dock',
  'docks',
  'docs',
  'doctor',
  'doctors',
  'document',
  'dodge',
  'dodo',
  'doe',
  'dog',
  'dogs',
  'doherty',
  'doing',
  'doings',
  'doll',
  'dollar',
  'dollars',
  'dolls',
  'dolly',
  'dolphin',
  'domain',
  'domains',
  'dome',
  'domes',
  'domicile',
  'dominion',
  'dominoes',
  'donkey',
  'donkeys',
  'doom',
  'door',
  'doorbell',
  'doorjamb',
  'doorknob',
  'doors',
  'doorstep',
  'doorway',
  'doorways',
  'dorm',
  'dosage',
  'dose',
  'doses',
  'dot',
  'dots',
  'doublet',
  'doughnut',
  'dove',
  'dover',
  'dowager',
  'download',
  'downs',
  'dowry',
  'dozen',
  'dozens',
  'drab',
  'draft',
  'drafts',
  'drag',
  'dragon',
  'dragons',
  'dragoon',
  'drags',
  'drama',
  'dramas',
  'drawback',
  'drawer',
  'drawers',
  'drawing',
  'drawings',
  'dream',
  'dreamer',
  'dreams',
  'dregs',
  'dresser',
  'dressing',
  'drift',
  'drinker',
  'drinkers',
  'dripping',
  'driver',
  'drivers',
  'driveway',
  'drizzle',
  'drone',
  'drones',
  'drop',
  'droplets',
  'dropping',
  'drops',
  'drove',
  'drug',
  'drugs',
  'drum',
  'drums',
  'drunkard',
  'duchess',
  'duck',
  'ducks',
  'duel',
  'dues',
  'duffel',
  'duke',
  'dummy',
  'dumping',
  'dumps',
  'dunce',
  'dung',
  'dungeon',
  'dungeons',
  'duo',
  'duration',
  'dust',
  'duties',
  'duty',
  'dvd',
  'dwarf',
  'dwarfs',
  'dwelling',
  'dye',
  'dyslexia',
  'eagle',
  'eagles',
  'ear',
  'earnest',
  'earnings',
  'earrings',
  'earshot',
  'earth',
  'ease',
  'eaves',
  'ebb',
  'ebony',
  'ebook',
  'ebooks',
  'echo',
  'echoes',
  'eclipse',
  'economy',
  'ecstasy',
  'eddies',
  'eddy',
  'eden',
  'edgar',
  'edge',
  'edges',
  'edging',
  'edition',
  'editor',
  'editors',
  'edward',
  'eels',
  'effect',
  'effects',
  'effort',
  'efforts',
  'ego',
  'egotism',
  'egypt',
  'eight',
  'eighteen',
  'eighth',
  'eighties',
  'eighty',
  'elation',
  'elbow',
  'elbows',
  'eld',
  'elder',
  'elders',
  'elds',
  'election',
  'elegance',
  'element',
  'elements',
  'elephant',
  'elevator',
  'eleven',
  'elite',
  'elm',
  'email',
  'embers',
  'emblem',
  'emerald',
  'emeralds',
  'emissary',
  'emotion',
  'emotions',
  'empathy',
  'emperor',
  'emphasis',
  'employee',
  'end',
  'ended',
  'ending',
  'ends',
  'enemies',
  'enemy',
  'energies',
  'energy',
  'engine',
  'engineer',
  'engines',
  'england',
  'enigma',
  'enmity',
  'ennui',
  'entirety',
  'entities',
  'entity',
  'entrance',
  'entreaty',
  'entries',
  'entropy',
  'entry',
  'entryway',
  'envelope',
  'envies',
  'environs',
  'envoy',
  'envy',
  'epilogue',
  'episode',
  'episodes',
  'epoch',
  'equality',
  'equals',
  'equation',
  'equator',
  'era',
  'erection',
  'errand',
  'errands',
  'error',
  'errors',
  'eruption',
  'escort',
  'escorts',
  'esquire',
  'ess',
  'essence',
  'estate',
  'estates',
  'esteem',
  'eternity',
  'ether',
  'ethics',
  'europe',
  'eve',
  'even',
  'evening',
  'event',
  'events',
  'everyone',
  'evidence',
  'evils',
  'exam',
  'example',
  'examples',
  'exams',
  'excess',
  'exchange',
  'executor',
  'exercise',
  'exertion',
  'exes',
  'exile',
  'exiles',
  'exits',
  'expanse',
  'expense',
  'expenses',
  'experts',
  'exploit',
  'explorer',
  'exposure',
  'extent',
  'extremes',
  'eye',
  'eyeballs',
  'eyebrow',
  'eyebrows',
  'eyeless',
  'eyelid',
  'eyelids',
  'eyes',
  'fable',
  'fables',
  'fabric',
  'facade',
  'face',
  'faces',
  'facet',
  'facets',
  'facility',
  'facing',
  'fact',
  'faction',
  'factor',
  'factors',
  'factory',
  'facts',
  'faculty',
  'failing',
  'failure',
  'failures',
  'fairy',
  'faith',
  'falcon',
  'fallout',
  'fame',
  'familiar',
  'families',
  'family',
  'famine',
  'fan',
  'fanfare',
  'fangs',
  'fanning',
  'fans',
  'fantasy',
  'farm',
  'farmer',
  'farming',
  'farms',
  'farthing',
  'fashion',
  'fashions',
  'fate',
  'fates',
  'father',
  'fathers',
  'fathom',
  'fathoms',
  'fatigue',
  'faucet',
  'fault',
  'faults',
  'fauna',
  'favor',
  'favorite',
  'favors',
  'fealty',
  'feast',
  'feasts',
  'feat',
  'feather',
  'feathers',
  'feature',
  'features',
  'february',
  'fed',
  'fee',
  'feedback',
  'feeling',
  'feelings',
  'fees',
  'feint',
  'fell',
  'fellow',
  'fellows',
  'felt',
  'females',
  'fence',
  'fences',
  'fencing',
  'fender',
  'ferns',
  'ferocity',
  'ferret',
  'fervor',
  'fester',
  'feud',
  'fever',
  'fiction',
  'field',
  'fields',
  'fifteen',
  'fifth',
  'fifty',
  'fighter',
  'figure',
  'figures',
  'filberts',
  'file',
  'files',
  'filling',
  'film',
  'films',
  'finances',
  'finding',
  'fine',
  'finger',
  'fingers',
  'fire',
  'fires',
  'firing',
  'fish',
  'fisher',
  'fishes',
  'fishing',
  'fist',
  'fists',
  'fit',
  'fits',
  'five',
  'fixing',
  'flag',
  'flags',
  'flame',
  'flames',
  'flanders',
  'flank',
  'flanks',
  'flap',
  'flare',
  'flashing',
  'flask',
  'flaw',
  'flaws',
  'flesh',
  'flight',
  'flights',
  'flint',
  'float',
  'flock',
  'flood',
  'floor',
  'floors',
  'flora',
  'florida',
  'flower',
  'flowers',
  'flurry',
  'flushing',
  'flux',
  'foam',
  'focus',
  'fodder',
  'foe',
  'foes',
  'fog',
  'fogs',
  'fold',
  'folder',
  'folders',
  'folds',
  'foliage',
  'folk',
  'folks',
  'follies',
  'follower',
  'follows',
  'folly',
  'fondness',
  'font',
  'food',
  'foods',
  'fool',
  'fools',
  'foot',
  'footage',
  'football',
  'footing',
  'footman',
  'footstep',
  'forage',
  'force',
  'forces',
  'ford',
  'forehead',
  'forest',
  'forested',
  'forester',
  'forests',
  'forfeit',
  'forfeits',
  'forge',
  'fork',
  'forks',
  'form',
  'format',
  'forms',
  'formula',
  'fort',
  'fortress',
  'fortune',
  'fortunes',
  'forty',
  'forum',
  'founder',
  'fountain',
  'four',
  'fours',
  'fourteen',
  'fourth',
  'fowl',
  'fowls',
  'fox',
  'foyer',
  'fraction',
  'fragment',
  'frailty',
  'framing',
  'france',
  'francis',
  'fraud',
  'fraught',
  'fraying',
  'freak',
  'freckles',
  'freedom',
  'freedoms',
  'freezer',
  'freight',
  'frenzy',
  'friction',
  'friday',
  'fridge',
  'friend',
  'friends',
  'fright',
  'fringe',
  'fringes',
  'frock',
  'frog',
  'frogs',
  'fronds',
  'front',
  'frontier',
  'fronts',
  'frost',
  'froth',
  'fruit',
  'fruits',
  'fuel',
  'fuller',
  'fullness',
  'fumes',
  'fun',
  'function',
  'fund',
  'funds',
  'fungus',
  'funnel',
  'furies',
  'furnace',
  'furrow',
  'furrows',
  'fury',
  'fuselage',
  'fusion',
  'fuss',
  'futility',
  'fuzz',
  'gad',
  'gadgets',
  'gaiety',
  'gain',
  'gains',
  'gait',
  'galaxy',
  'gale',
  'galen',
  'gallant',
  'gallery',
  'galley',
  'gallows',
  'gambit',
  'game',
  'games',
  'gap',
  'gaps',
  'garage',
  'garb',
  'garbage',
  'garden',
  'gardens',
  'gardner',
  'garlic',
  'garment',
  'garments',
  'garret',
  'garrison',
  'gas',
  'gash',
  'gashes',
  'gasoline',
  'gate',
  'gates',
  'gateway',
  'gauge',
  'gauntlet',
  'gauze',
  'gawk',
  'gear',
  'gearing',
  'gears',
  'gel',
  'gem',
  'gems',
  'gender',
  'gene',
  'generals',
  'genes',
  'genesis',
  'genius',
  'genocide',
  'genre',
  'geometry',
  'george',
  'georgia',
  'georgian',
  'german',
  'germans',
  'germany',
  'gerry',
  'gesture',
  'gestures',
  'gets',
  'geyser',
  'ghost',
  'ghosts',
  'giant',
  'giants',
  'gift',
  'gifts',
  'gills',
  'ginger',
  'girders',
  'girdle',
  'girl',
  'girlhood',
  'girls',
  'gist',
  'glacier',
  'glamour',
  'glass',
  'glasses',
  'gleam',
  'glee',
  'globe',
  'globes',
  'glory',
  'glove',
  'gloves',
  'gnats',
  'goad',
  'goal',
  'goals',
  'goat',
  'goats',
  'goblet',
  'goblets',
  'god',
  'goddamn',
  'goddess',
  'gods',
  'goggles',
  'gogh',
  'going',
  'gold',
  'goodbye',
  'goodness',
  'goods',
  'goodwill',
  'goose',
  'gordon',
  'gore',
  'gorge',
  'gospel',
  'gossamer',
  'gossip',
  'gout',
  'gouts',
  'governor',
  'gown',
  'gowns',
  'grace',
  'graces',
  'grade',
  'gradual',
  'graduate',
  'grail',
  'grain',
  'grains',
  'grammar',
  'grandeur',
  'grandma',
  'grandson',
  'granite',
  'grape',
  'grapes',
  'graphs',
  'grapple',
  'grass',
  'grasses',
  'grating',
  'gravel',
  'graves',
  'gravity',
  'gravy',
  'grays',
  'grazing',
  'grease',
  'greed',
  'greek',
  'greenery',
  'greeting',
  'grid',
  'griddle',
  'grief',
  'griefs',
  'grimace',
  'grimaced',
  'grime',
  'grit',
  'grocer',
  'grocery',
  'groin',
  'groom',
  'grooms',
  'groove',
  'grooves',
  'ground',
  'grounds',
  'group',
  'grouping',
  'groups',
  'grove',
  'growth',
  'growths',
  'gruel',
  'guard',
  'guardian',
  'guards',
  'guest',
  'guests',
  'guffawed',
  'guidance',
  'guide',
  'guides',
  'guilt',
  'guinea',
  'guise',
  'guitar',
  'gulf',
  'gull',
  'gulls',
  'gum',
  'gums',
  'gun',
  'gunk',
  'gunmetal',
  'gunner',
  'gunners',
  'gunnery',
  'guns',
  'gunshot',
  'gurney',
  'gust',
  'gusto',
  'gusts',
  'gut',
  'guts',
  'gutter',
  'gutters',
  'guy',
  'guys',
  'gym',
  'habit',
  'habits',
  'haft',
  'hail',
  'hair',
  'hippo',
  'hairs',
  'half',
  'hall',
  'halls',
  'hallway',
  'hallways',
  'halo',
  'halter',
  'ham',
  'hamlet',
  'hammer',
  'hammers',
  'hams',
  'hand',
  'handful',
  'handfuls',
  'handgun',
  'handhold',
  'handle',
  'handled',
  'handles',
  'handling',
  'hangar',
  'hanger',
  'hangers',
  'hangings',
  'hangman',
  'hank',
  'harbor',
  'hardness',
  'hardship',
  'hardware',
  'hardwood',
  'hare',
  'harem',
  'harm',
  'harmony',
  'harness',
  'harp',
  'harper',
  'hartwell',
  'harvest',
  'haste',
  'hat',
  'hatch',
  'hatches',
  'hatching',
  'hatchway',
  'hate',
  'hates',
  'hatred',
  'hats',
  'haunches',
  'haven',
  'havoc',
  'hawk',
  'hawking',
  'hawks',
  'hay',
  'hazard',
  'hazards',
  'haze',
  'hazel',
  'head',
  'headache',
  'headband',
  'heading',
  'heads',
  'headset',
  'healer',
  'healers',
  'health',
  'heap',
  'heaps',
  'heard',
  'hearing',
  'hearse',
  'heart',
  'hearth',
  'hearths',
  'hearts',
  'heater',
  'heaven',
  'heavens',
  'hebrew',
  'heck',
  'hedge',
  'hedges',
  'heel',
  'heels',
  'height',
  'heights',
  'heir',
  'heirs',
  'hell',
  'hello',
  'hells',
  'helm',
  'helmet',
  'helmeted',
  'helmets',
  'helpers',
  'helping',
  'hem',
  'hemp',
  'hen',
  'henley',
  'henry',
  'herb',
  'herbal',
  'herbs',
  'hercules',
  'herd',
  'herds',
  'heresy',
  'heretics',
  'heritage',
  'hermit',
  'hero',
  'heroes',
  'heroism',
  'herself',
  'hide',
  'hides',
  'highness',
  'highway',
  'highways',
  'hill',
  'hills',
  'hillside',
  'hilt',
  'him',
  'himself',
  'hind',
  'hinge',
  'hinges',
  'hint',
  'hints',
  'hip',
  'hips',
  'hire',
  'history',
  'hive',
  'hoard',
  'hobbies',
  'hobby',
  'hockey',
  'hog',
  'holder',
  'holders',
  'holding',
  'hole',
  'holes',
  'holiday',
  'holiness',
  'hollow',
  'hollows',
  'holly',
  'holster',
  'holsters',
  'homage',
  'home',
  'homeland',
  'homes',
  'homework',
  'homicide',
  'honesty',
  'honey',
  'honor',
  'honors',
  'hood',
  'hoods',
  'hoof',
  'hoofs',
  'hook',
  'hooks',
  'hoop',
  'hoops',
  'hooves',
  'horizon',
  'hormone',
  'horn',
  'horns',
  'horror',
  'horrors',
  'horse',
  'horseman',
  'horsemen',
  'horses',
  'hose',
  'hospital',
  'host',
  'hostage',
  'hostages',
  'hostess',
  'hosts',
  'hotel',
  'hotels',
  'hound',
  'hounds',
  'hour',
  'house',
  'houses',
  'housing',
  'hovel',
  'hovels',
  'hub',
  'hue',
  'hues',
  'hulk',
  'hull',
  'hulls',
  'humanity',
  'humans',
  'humility',
  'humor',
  'humors',
  'hump',
  'hundred',
  'hundreds',
  'hunger',
  'hunk',
  'hunter',
  'hunters',
  'hunting',
  'hurling',
  'hurrah',
  'husband',
  'husbands',
  'hut',
  'huts',
  'hydrogen',
  'hysteria',
  'ice',
  'iceberg',
  'icicle',
  'icicles',
  'icon',
  'icons',
  'ict',
  'idea',
  'idealist',
  'ideals',
  'ideas',
  'identity',
  'idiocy',
  'idiot',
  'idiots',
  'idol',
  'idols',
  'ignition',
  'ignominy',
  'iii',
  'illness',
  'illusion',
  'image',
  'imagery',
  'images',
  'imbecile',
  'imp',
  'impunity',
  'incense',
  'inch',
  'inches',
  'incident',
  'income',
  'incoming',
  'index',
  'indian',
  'indians',
  'indigo',
  'industry',
  'inertia',
  'infancy',
  'infant',
  'infantry',
  'infants',
  'inferno',
  'info',
  'ingrate',
  'initials',
  'injuries',
  'injury',
  'ink',
  'inkling',
  'inks',
  'inky',
  'inlet',
  'inn',
  'inns',
  'input',
  'inquiry',
  'insanity',
  'insect',
  'insects',
  'inside',
  'insides',
  'insight',
  'insights',
  'insignia',
  'instance',
  'instant',
  'instinct',
  'intake',
  'intakes',
  'intent',
  'intercom',
  'interest',
  'internet',
  'interval',
  'intimacy',
  'intrigue',
  'invasion',
  'ire',
  'irises',
  'irish',
  'irishman',
  'iron',
  'irons',
  'ironwork',
  'irony',
  'island',
  'islands',
  'isle',
  'isles',
  'israel',
  'issue',
  'issues',
  'italian',
  'items',
  'itself',
  'ivory',
  'ivy',
  'jack',
  'jackal',
  'jacket',
  'jackets',
  'jackson',
  'jacob',
  'jacques',
  'jade',
  'jail',
  'jailer',
  'jailers',
  'jamb',
  'james',
  'january',
  'jargon',
  'jasmine',
  'jaw',
  'jawline',
  'jaws',
  'jay',
  'jazz',
  'jealousy',
  'jean',
  'jeans',
  'jeffrey',
  'jelly',
  'jeopardy',
  'jerk',
  'jerks',
  'jess',
  'jest',
  'jesting',
  'jests',
  'jesus',
  'jet',
  'jets',
  'jetty',
  'jew',
  'jewel',
  'jewelry',
  'jewels',
  'jewess',
  'jig',
  'jigsaw',
  'jim',
  'job',
  'jobs',
  'joe',
  'john',
  'joining',
  'joint',
  'jointed',
  'joints',
  'joke',
  'joker',
  'jokes',
  'jones',
  'joseph',
  'journal',
  'journey',
  'journeys',
  'jove',
  'jowl',
  'jowls',
  'joy',
  'joys',
  'joystick',
  'juan',
  'judas',
  'judges',
  'judgment',
  'judith',
  'jug',
  'juice',
  'july',
  'jumpsuit',
  'junction',
  'juncture',
  'june',
  'jungle',
  'junk',
  'jupiter',
  'jurors',
  'jury',
  'justice',
  'kay',
  'keeper',
  'keepers',
  'keeping',
  'keepsake',
  'kerchief',
  'kettle',
  'key',
  'keyboard',
  'keyed',
  'keyhole',
  'keypad',
  'keys',
  'kid',
  'kiddies',
  'kidneys',
  'kids',
  'killer',
  'killers',
  'killing',
  'kin',
  'kind',
  'kindling',
  'kindness',
  'kindred',
  'kinds',
  'king',
  'kingdom',
  'kingdoms',
  'kinks',
  'kinship',
  'kit',
  'kitchen',
  'kitchens',
  'kits',
  'kittens',
  'kitty',
  'knack',
  'knee',
  'kneecap',
  'knees',
  'knife',
  'knight',
  'knitting',
  'knives',
  'knob',
  'knobby',
  'knocker',
  'knot',
  'knots',
  'knowing',
  'knuckle',
  'knuckled',
  'knuckles',
  'kudzu',
  'lab',
  'label',
  'labels',
  'labor',
  'laborer',
  'laborers',
  'labors',
  'lacing',
  'lad',
  'ladder',
  'ladders',
  'ladies',
  'ladle',
  'lads',
  'lady',
  'lag',
  'lair',
  'lake',
  'lamb',
  'lambs',
  'lamp',
  'lamps',
  'lance',
  'land',
  'landing',
  'landings',
  'landlord',
  'lands',
  'lane',
  'lanes',
  'language',
  'lantern',
  'lanterns',
  'lap',
  'laps',
  'lapse',
  'lar',
  'larder',
  'larynx',
  'las',
  'laser',
  'lasers',
  'lashing',
  'lass',
  'latex',
  'latino',
  'lattice',
  'lattices',
  'laughter',
  'laundry',
  'lava',
  'lavatory',
  'lavender',
  'law',
  'lawn',
  'laws',
  'lawyer',
  'layer',
  'layered',
  'layers',
  'layout',
  'lea',
  'leader',
  'leaders',
  'leaf',
  'leafless',
  'league',
  'leagues',
  'leaning',
  'learning',
  'lease',
  'leash',
  'leather',
  'leathers',
  'leavings',
  'lectern',
  'lecture',
  'lectures',
  'ledge',
  'ledger',
  'ledgers',
  'ledges',
  'lee',
  'leeches',
  'leftover',
  'leg',
  'legacy',
  'legend',
  'legends',
  'leggings',
  'legion',
  'legs',
  'leisure',
  'lemon',
  'lemons',
  'length',
  'lengths',
  'lens',
  'lenses',
  'lent',
  'leo',
  'lesson',
  'lessons',
  'lethargy',
  'letter',
  'letters',
  'level',
  'levels',
  'lever',
  'leverage',
  'levers',
  'levin',
  'lewis',
  'liar',
  'liberty',
  'library',
  'license',
  'licensed',
  'lichen',
  'licking',
  'lid',
  'lids',
  'lied',
  'lieu',
  'life',
  'lifetime',
  'lift',
  'light',
  'lighter',
  'lighting',
  'lights',
  'likeness',
  'liking',
  'lilac',
  'lilies',
  'lilt',
  'lily',
  'limb',
  'limbs',
  'lime',
  'limit',
  'limits',
  'lincoln',
  'linda',
  'line',
  'lineage',
  'lines',
  'ling',
  'lingerie',
  'lining',
  'link',
  'links',
  'lion',
  'lions',
  'lip',
  'lips',
  'lipstick',
  'liquor',
  'lisa',
  'listing',
  'listings',
  'litany',
  'litter',
  'liver',
  'livery',
  'lizard',
  'lizards',
  'load',
  'loading',
  'loads',
  'loaf',
  'loan',
  'loathing',
  'loaves',
  'lobby',
  'lobe',
  'locale',
  'locality',
  'locals',
  'location',
  'lock',
  'locker',
  'lockers',
  'locks',
  'lodging',
  'loft',
  'log',
  'logic',
  'logo',
  'logs',
  'loins',
  'london',
  'longing',
  'lookers',
  'lookout',
  'loom',
  'looms',
  'loop',
  'loophole',
  'loops',
  'loot',
  'lord',
  'lords',
  'lordship',
  'lore',
  'lorry',
  'loser',
  'loss',
  'losses',
  'lot',
  'lottery',
  'louis',
  'love',
  'lover',
  'loves',
  'loyalty',
  'lozenge',
  'lucidity',
  'luck',
  'luggage',
  'lullaby',
  'lump',
  'lumps',
  'lunch',
  'lunge',
  'lungful',
  'lungs',
  'lure',
  'lust',
  'luster',
  'luxuries',
  'luxury',
  'machine',
  'machines',
  'madam',
  'madame',
  'madder',
  'madhouse',
  'madman',
  'madness',
  'madwoman',
  'magazine',
  'magic',
  'magician',
  'magnate',
  'mahogany',
  'maid',
  'maiden',
  'maidens',
  'maids',
  'mail',
  'mailbox',
  'main',
  'majesty',
  'majority',
  'maker',
  'makers',
  'makeup',
  'making',
  'makings',
  'malady',
  'male',
  'males',
  'malice',
  'mall',
  'mama',
  'man',
  'manager',
  'managers',
  'mandarin',
  'mane',
  'maneuver',
  'manhood',
  'mania',
  'maniac',
  'manner',
  'manners',
  'manor',
  'mansion',
  'mansions',
  'mantle',
  'map',
  'maple',
  'maps',
  'marble',
  'marbles',
  'march',
  'marches',
  'marcus',
  'mare',
  'margin',
  'margins',
  'marie',
  'marines',
  'mark',
  'marker',
  'markers',
  'market',
  'markets',
  'marking',
  'markings',
  'marks',
  'maroon',
  'marquis',
  'marriage',
  'marrow',
  'mars',
  'marshal',
  'marshes',
  'martin',
  'martyr',
  'marvel',
  'marvels',
  'mary',
  'mask',
  'masks',
  'mass',
  'massacre',
  'massage',
  'masse',
  'masses',
  'mast',
  'master',
  'mastery',
  'masts',
  'mat',
  'match',
  'matches',
  'mates',
  'math',
  'matrix',
  'matron',
  'mats',
  'matter',
  'matters',
  'matthew',
  'mattress',
  'maturity',
  'mauve',
  'max',
  'maximum',
  'may',
  'mayhem',
  'mayor',
  'meadow',
  'meadows',
  'meal',
  'meals',
  'meaning',
  'meanings',
  'meantime',
  'measure',
  'measures',
  'meat',
  'medals',
  'media',
  'medicine',
  'medium',
  'medusa',
  'meeting',
  'meetings',
  'melee',
  'melodic',
  'melody',
  'melon',
  'member',
  'members',
  'membrane',
  'memories',
  'memory',
  'menace',
  'mention',
  'mentions',
  'mentor',
  'menu',
  'menus',
  'merchant',
  'mercury',
  'mercy',
  'mere',
  'merit',
  'merits',
  'mesh',
  'mess',
  'message',
  'messages',
  'metal',
  'metals',
  'metaphor',
  'meter',
  'meters',
  'method',
  'methods',
  'metric',
  'mexican',
  'mexico',
  'michael',
  'midair',
  'midday',
  'midnight',
  'midriff',
  'midst',
  'milady',
  'mildew',
  'mile',
  'miles',
  'militia',
  'milk',
  'mill',
  'miller',
  'milling',
  'million',
  'millions',
  'mimic',
  'mimicry',
  'mind',
  'minds',
  'mineral',
  'mines',
  'mini',
  'minimum',
  'mining',
  'minions',
  'minister',
  'minority',
  'mint',
  'minute',
  'minutes',
  'miracle',
  'miracles',
  'mirage',
  'mire',
  'mirror',
  'mirrored',
  'mirrors',
  'mirth',
  'mischief',
  'misery',
  'missiles',
  'mission',
  'missions',
  'misstep',
  'mist',
  'mister',
  'mistress',
  'mistrust',
  'mists',
  'mixture',
  'moan',
  'moans',
  'moat',
  'mob',
  'mockery',
  'mode',
  'model',
  'models',
  'modesty',
  'module',
  'moi',
  'moisture',
  'molars',
  'mold',
  'mole',
  'molecule',
  'moles',
  'mom',
  'moment',
  'moments',
  'momentum',
  'mon',
  'monarch',
  'monday',
  'mondays',
  'money',
  'monitor',
  'monitors',
  'monk',
  'monkey',
  'monkeys',
  'monks',
  'monotone',
  'monsieur',
  'monster',
  'monsters',
  'month',
  'months',
  'monument',
  'mood',
  'moods',
  'moon',
  'moonbeam',
  'moons',
  'moot',
  'mop',
  'mops',
  'morale',
  'morality',
  'morals',
  'morning',
  'morrow',
  'morsel',
  'mortals',
  'mortar',
  'moses',
  'moss',
  'motes',
  'moth',
  'mother',
  'mothers',
  'moths',
  'motion',
  'motions',
  'motive',
  'motives',
  'motor',
  'motors',
  'mottled',
  'motto',
  'mount',
  'mountain',
  'mounting',
  'mounts',
  'mourning',
  'mouse',
  'mouth',
  'mouthful',
  'mouths',
  'movement',
  'movie',
  'movies',
  'muck',
  'mud',
  'mug',
  'mugs',
  'mule',
  'mules',
  'murder',
  'murderer',
  'murders',
  'murk',
  'murmur',
  'murmurs',
  'muscle',
  'muscles',
  'museum',
  'mushroom',
  'music',
  'musing',
  'musk',
  'musket',
  'muskets',
  'mustache',
  'mustard',
  'muster',
  'mutiny',
  'mutton',
  'muzzle',
  'muzzles',
  'myriad',
  'myself',
  'mystery',
  'myth',
  'nail',
  'nails',
  'name',
  'names',
  'namesake',
  'nancy',
  'nape',
  'napkin',
  'napkins',
  'napoleon',
  'narcotic',
  'nasal',
  'nation',
  'nations',
  'natives',
  'nature',
  'natures',
  'naught',
  'nausea',
  'navel',
  'navy',
  'neat',
  'nebula',
  'neck',
  'necklace',
  'neckline',
  'necks',
  'nectar',
  'need',
  'needle',
  'needles',
  'negro',
  'neighbor',
  'nelson',
  'neon',
  'nephew',
  'nerve',
  'nerves',
  'ness',
  'nest',
  'nests',
  'net',
  'nets',
  'netting',
  'network',
  'neuron',
  'neutral',
  'newcomer',
  'newton',
  'niceties',
  'nicety',
  'niche',
  'nick',
  'nickname',
  'niece',
  'night',
  'nightcap',
  'nimbus',
  'nine',
  'nineteen',
  'ninety',
  'ning',
  'ninny',
  'ninth',
  'nipple',
  'nipples',
  'nish',
  'nobility',
  'nobleman',
  'nobles',
  'nobody',
  'nodes',
  'noise',
  'noises',
  'nonsense',
  'nook',
  'nooks',
  'noon',
  'nor',
  'nose',
  'noses',
  'nosing',
  'nostril',
  'nostrils',
  'notation',
  'notch',
  'notebook',
  'nothing',
  'notice',
  'notices',
  'notion',
  'notions',
  'noun',
  'novels',
  'novelty',
  'november',
  'novice',
  'novices',
  'nuance',
  'nuances',
  'nub',
  'nuisance',
  'nuke',
  'nukes',
  'number',
  'nurse',
  'nursery',
  'nurses',
  'nursing',
  'nut',
  'nylon',
  'oak',
  'oaks',
  'oars',
  'oasis',
  'oat',
  'oath',
  'oaths',
  'object',
  'objects',
  'oblivion',
  'observer',
  'obstacle',
  'occasion',
  'occupant',
  'ocean',
  'oceans',
  'octave',
  'october',
  'oddity',
  'odds',
  'odor',
  'odyssey',
  'offense',
  'offenses',
  'offering',
  'office',
  'officer',
  'officers',
  'offices',
  'official',
  'offset',
  'ogre',
  'ohio',
  'oil',
  'oils',
  'ointment',
  'olds',
  'olive',
  'omelet',
  'omen',
  'omnibus',
  'ones',
  'oneself',
  'onion',
  'onions',
  'onset',
  'ooze',
  'opener',
  'opening',
  'openings',
  'operator',
  'opiate',
  'opinion',
  'opinions',
  'opponent',
  'ops',
  'optimism',
  'optimist',
  'optimum',
  'option',
  'options',
  'orange',
  'oranges',
  'orb',
  'orbit',
  'orbital',
  'orbits',
  'orbs',
  'orchard',
  'orchards',
  'orchid',
  'ordeal',
  'ordinary',
  'ordnance',
  'ore',
  'oregon',
  'organ',
  'organs',
  'orgasm',
  'origin',
  'original',
  'origins',
  'orlando',
  'ornament',
  'orphan',
  'orphans',
  'ostrich',
  'others',
  'ounce',
  'outburst',
  'outcome',
  'outcomes',
  'outcry',
  'outfit',
  'outing',
  'outlet',
  'outlets',
  'outline',
  'outlines',
  'outlook',
  'outpost',
  'output',
  'outrage',
  'outside',
  'outsider',
  'oval',
  'ovals',
  'oven',
  'overalls',
  'overcoat',
  'overseer',
  'overview',
  'owl',
  'owls',
  'oxcart',
  'oxen',
  'oxford',
  'oxygen',
  'oyster',
  'oysters',
  'ozone',
  'pace',
  'paces',
  'pack',
  'package',
  'packages',
  'packet',
  'packets',
  'packing',
  'packs',
  'pact',
  'padding',
  'pagan',
  'page',
  'pageant',
  'pages',
  'pail',
  'pain',
  'painless',
  'pains',
  'painter',
  'painting',
  'pair',
  'pairs',
  'pajama',
  'pajamas',
  'pal',
  'palace',
  'palaces',
  'palate',
  'pale',
  'pallet',
  'pallets',
  'pallor',
  'palm',
  'palmetto',
  'palms',
  'pan',
  'pancakes',
  'pane',
  'panel',
  'paneling',
  'panels',
  'panes',
  'pang',
  'pangs',
  'panicky',
  'pans',
  'panther',
  'panties',
  'pantry',
  'pap',
  'paper',
  'papers',
  'par',
  'para',
  'parade',
  'paradise',
  'paradox',
  'paranoia',
  'parapets',
  'parasite',
  'parasol',
  'parcels',
  'pardon',
  'pardons',
  'parent',
  'parental',
  'parents',
  'paris',
  'parish',
  'park',
  'parks',
  'parlor',
  'parody',
  'parole',
  'parrot',
  'part',
  'particle',
  'parties',
  'parting',
  'partner',
  'partners',
  'parts',
  'party',
  'passage',
  'passages',
  'passing',
  'passion',
  'passions',
  'password',
  'pasta',
  'paste',
  'pastime',
  'pastry',
  'pasture',
  'pastures',
  'pasty',
  'pat',
  'patch',
  'patches',
  'pate',
  'path',
  'paths',
  'pathway',
  'pathways',
  'patience',
  'patients',
  'patina',
  'patio',
  'patrick',
  'patrol',
  'patrols',
  'patron',
  'patrons',
  'pattern',
  'patterns',
  'paul',
  'paupers',
  'pause',
  'pauses',
  'pavement',
  'pavilion',
  'paving',
  'paw',
  'pawn',
  'paws',
  'payment',
  'payments',
  'pdf',
  'peace',
  'peach',
  'peaches',
  'peacock',
  'peak',
  'peal',
  'peals',
  'pearl',
  'pearls',
  'peas',
  'peasant',
  'peasants',
  'pebble',
  'pebbles',
  'peck',
  'peddler',
  'peddlers',
  'pedestal',
  'peeling',
  'peephole',
  'peer',
  'peers',
  'peg',
  'pelt',
  'pelts',
  'pelvis',
  'penalty',
  'penance',
  'pencil',
  'pencils',
  'pendant',
  'pendulum',
  'pennants',
  'penny',
  'people',
  'pepper',
  'perch',
  'perches',
  'perfume',
  'perfumes',
  'peril',
  'perils',
  'period',
  'periods',
  'person',
  'persona',
  'persons',
  'pet',
  'petals',
  'peters',
  'petition',
  'petri',
  'pets',
  'phantom',
  'phase',
  'phone',
  'phones',
  'photo',
  'photos',
  'phrase',
  'phrases',
  'physics',
  'physique',
  'pickings',
  'pickle',
  'pickup',
  'picnic',
  'picture',
  'pictures',
  'pie',
  'piece',
  'pieces',
  'pier',
  'pierre',
  'pig',
  'pigeon',
  'pigeons',
  'pike',
  'pikes',
  'pile',
  'piles',
  'piling',
  'pillar',
  'pillars',
  'pillow',
  'pillows',
  'pilot',
  'pilots',
  'pimple',
  'pin',
  'pine',
  'pines',
  'pinioned',
  'pinions',
  'pink',
  'pinpoint',
  'pint',
  'pioneer',
  'pipe',
  'pipes',
  'piping',
  'piracy',
  'pirate',
  'pirates',
  'pistol',
  'pistols',
  'pit',
  'pitch',
  'pitcher',
  'pits',
  'pity',
  'pivot',
  'pizza',
  'place',
  'places',
  'plague',
  'plaid',
  'plan',
  'planet',
  'planets',
  'plank',
  'planks',
  'planning',
  'plans',
  'planting',
  'plaques',
  'plaster',
  'plate',
  'plateau',
  'plates',
  'platform',
  'plating',
  'platoon',
  'platter',
  'platters',
  'play',
  'player',
  'players',
  'plays',
  'plaza',
  'plea',
  'pleading',
  'pleas',
  'pleasure',
  'pledge',
  'plenty',
  'plot',
  'plots',
  'ploy',
  'plug',
  'plum',
  'plumbing',
  'plume',
  'plumes',
  'plums',
  'plush',
  'pocket',
  'pockets',
  'pod',
  'podium',
  'pods',
  'poem',
  'poems',
  'poet',
  'poetry',
  'poets',
  'point',
  'points',
  'poison',
  'poisons',
  'poke',
  'poker',
  'pole',
  'poles',
  'policies',
  'policy',
  'politics',
  'polo',
  'pommel',
  'pomp',
  'pond',
  'ponds',
  'ponies',
  'pony',
  'ponytail',
  'pool',
  'pools',
  'pope',
  'poppies',
  'populace',
  'porch',
  'pork',
  'porridge',
  'port',
  'portal',
  'porter',
  'porters',
  'porthole',
  'portion',
  'portions',
  'portrait',
  'ports',
  'position',
  'possum',
  'post',
  'poster',
  'posting',
  'postings',
  'posts',
  'posture',
  'pot',
  'potato',
  'potatoes',
  'potion',
  'potions',
  'pouch',
  'pouches',
  'pounce',
  'pound',
  'pounds',
  'poverty',
  'power',
  'powers',
  'prayer',
  'prayers',
  'preamble',
  'predator',
  'prelude',
  'prep',
  'presence',
  'present',
  'presents',
  'press',
  'presses',
  'pressure',
  'prestige',
  'pretense',
  'pretext',
  'prey',
  'price',
  'prices',
  'prick',
  'prickle',
  'pride',
  'priest',
  'priests',
  'primate',
  'prime',
  'prince',
  'princes',
  'princess',
  'print',
  'printer',
  'printing',
  'printout',
  'prints',
  'prior',
  'priority',
  'prism',
  'prison',
  'prisoner',
  'prisons',
  'privacy',
  'prize',
  'pro',
  'probe',
  'probes',
  'problem',
  'problems',
  'proceeds',
  'process',
  'prod',
  'prods',
  'producer',
  'product',
  'products',
  'profile',
  'profit',
  'program',
  'programs',
  'progress',
  'project',
  'projects',
  'prologue',
  'promise',
  'promises',
  'pronoun',
  'proof',
  'proofs',
  'prop',
  'property',
  'prophecy',
  'prophet',
  'proposal',
  'prospect',
  'protein',
  'protest',
  'protests',
  'protocol',
  'provider',
  'province',
  'proxy',
  'prudence',
  'psyche',
  'puddle',
  'puddles',
  'puffy',
  'pulley',
  'pulleys',
  'pulp',
  'pulpit',
  'pulse',
  'pulses',
  'pump',
  'pumps',
  'punch',
  'punches',
  'puncture',
  'pup',
  'pupil',
  'pupils',
  'puppet',
  'puppets',
  'puppies',
  'puppy',
  'puri',
  'purity',
  'purpose',
  'purposes',
  'purse',
  'purses',
  'pursuit',
  'pursuits',
  'putty',
  'pyramid',
  'pyramids',
  'pyre',
  'python',
  'quadrant',
  'quality',
  'qualms',
  'quandary',
  'quantity',
  'quantum',
  'quarrel',
  'quarry',
  'quarter',
  'quarters',
  'quartet',
  'quay',
  'queen',
  'queens',
  'queries',
  'query',
  'quest',
  'question',
  'queue',
  'quiet',
  'quill',
  'quirk',
  'quiver',
  'rabbit',
  'rabbits',
  'race',
  'races',
  'racing',
  'racism',
  'rack',
  'racket',
  'racks',
  'radar',
  'radiance',
  'radius',
  'raft',
  'rafters',
  'rag',
  'rage',
  'rags',
  'raid',
  'raids',
  'rail',
  'railing',
  'railings',
  'rails',
  'railway',
  'rain',
  'rainbow',
  'rainbows',
  'rains',
  'raisins',
  'rake',
  'rakes',
  'ram',
  'rami',
  'ramrod',
  'rams',
  'rancor',
  'random',
  'range',
  'rangers',
  'ranges',
  'ranks',
  'ransom',
  'rap',
  'rape',
  'rapidity',
  'raptor',
  'rapture',
  'rascal',
  'rat',
  'ratio',
  'ration',
  'rations',
  'raven',
  'ravens',
  'ravine',
  'ravines',
  'raving',
  'ray',
  'rays',
  'razor',
  'reaction',
  'reactor',
  'reactors',
  'reader',
  'readers',
  'reading',
  'readings',
  'readout',
  'readouts',
  'reality',
  'realm',
  'realms',
  'rearview',
  'reason',
  'reasons',
  'rebels',
  'receipt',
  'receiver',
  'receptor',
  'recess',
  'recesses',
  'recipe',
  'recital',
  'recon',
  'recorder',
  'recourse',
  'recovery',
  'redhead',
  'redness',
  'reds',
  'reed',
  'reeds',
  'reefs',
  'reek',
  'reflex',
  'reflexes',
  'refuge',
  'refugee',
  'refugees',
  'refusal',
  'reg',
  'regard',
  'regards',
  'regent',
  'regime',
  'regiment',
  'region',
  'regions',
  'register',
  'registry',
  'reign',
  'rein',
  'reins',
  'relation',
  'relative',
  'relay',
  'relays',
  'relic',
  'relics',
  'relief',
  'religion',
  'relish',
  'remark',
  'remarks',
  'remedies',
  'remedy',
  'remnant',
  'remnants',
  'remorse',
  'removal',
  'renegade',
  'renewal',
  'rent',
  'rental',
  'rents',
  'repast',
  'report',
  'reports',
  'reproach',
  'republic',
  'request',
  'requests',
  'res',
  'research',
  'residue',
  'resort',
  'resource',
  'respect',
  'respects',
  'respite',
  'respond',
  'response',
  'rest',
  'rests',
  'retainer',
  'retinas',
  'retinue',
  'retreat',
  'reunion',
  'revelry',
  'reverie',
  'review',
  'rhetoric',
  'rhyme',
  'rhythm',
  'rhythms',
  'rib',
  'ribbon',
  'ribbons',
  'ribs',
  'rice',
  'richard',
  'riches',
  'rider',
  'riders',
  'ridge',
  'ridged',
  'ridges',
  'ridicule',
  'riding',
  'rift',
  'rigging',
  'rights',
  'rim',
  'ring',
  'ringer',
  'ringlets',
  'rings',
  'riot',
  'riots',
  'rising',
  'risk',
  'risks',
  'rite',
  'rites',
  'rituals',
  'rival',
  'rivals',
  'river',
  'rivers',
  'rivulets',
  'road',
  'roads',
  'roadside',
  'roadway',
  'robbery',
  'robe',
  'robes',
  'robin',
  'robot',
  'robots',
  'rocket',
  'rockets',
  'rod',
  'rodent',
  'rodents',
  'rods',
  'rogue',
  'role',
  'roles',
  'roll',
  'roller',
  'rolls',
  'roman',
  'romances',
  'rome',
  'romeo',
  'roof',
  'roofs',
  'rooftop',
  'rooftops',
  'room',
  'rooms',
  'root',
  'rooted',
  'roots',
  'rope',
  'ropes',
  'rosary',
  'rosemary',
  'roses',
  'rosewood',
  'roster',
  'rotation',
  'rounds',
  'rout',
  'route',
  'routes',
  'routine',
  'routines',
  'rover',
  'royalty',
  'rst',
  'rubber',
  'rubbing',
  'rubbish',
  'rubble',
  'rubies',
  'ruby',
  'rudder',
  'rug',
  'rugs',
  'ruin',
  'ruins',
  'rule',
  'ruler',
  'rules',
  'ruling',
  'rum',
  'rumbling',
  'rumor',
  'rumors',
  'runaway',
  'runnels',
  'runner',
  'runners',
  'running',
  'runs',
  'ruse',
  'rush',
  'rushes',
  'rushing',
  'russet',
  'russian',
  'rust',
  'ruts',
  'saber',
  'sable',
  'sack',
  'sacks',
  'saddle',
  'saddles',
  'sadistic',
  'safety',
  'saffron',
  'sail',
  'sailed',
  'sailing',
  'sailor',
  'sailors',
  'sails',
  'saint',
  'saints',
  'sake',
  'salad',
  'salary',
  'sale',
  'saliva',
  'sallow',
  'sally',
  'salmon',
  'salt',
  'salts',
  'salvage',
  'salve',
  'salver',
  'salvo',
  'sample',
  'samples',
  'sampling',
  'samuel',
  'san',
  'sanctity',
  'sanctum',
  'sand',
  'sandals',
  'sands',
  'sandwich',
  'sanity',
  'santa',
  'sap',
  'sapphire',
  'sarcasm',
  'sash',
  'sashes',
  'satan',
  'satchel',
  'satin',
  'saturday',
  'sauce',
  'saucepan',
  'saucer',
  'saucers',
  'sauna',
  'sausage',
  'sausages',
  'savages',
  'saving',
  'savings',
  'savior',
  'sawdust',
  'sawyer',
  'saying',
  'scabbard',
  'scaffold',
  'scale',
  'scales',
  'scalp',
  'scandal',
  'scandals',
  'scanner',
  'scanners',
  'scar',
  'scarf',
  'scarlet',
  'scars',
  'scarves',
  'scenario',
  'scene',
  'scenery',
  'scent',
  'scents',
  'schedule',
  'scheme',
  'schemes',
  'scholar',
  'scholars',
  'school',
  'schools',
  'science',
  'sciences',
  'scissors',
  'scold',
  'scolding',
  'scoop',
  'scope',
  'score',
  'scores',
  'scorn',
  'scott',
  'scouring',
  'scouting',
  'scrap',
  'scraps',
  'screech',
  'screen',
  'screens',
  'screw',
  'screws',
  'script',
  'scripts',
  'scroll',
  'scrolled',
  'scrolls',
  'scrub',
  'scrutiny',
  'scullery',
  'sculptor',
  'scum',
  'scuttle',
  'sea',
  'seagull',
  'seagulls',
  'seal',
  'seals',
  'seam',
  'seams',
  'seas',
  'season',
  'seasons',
  'seat',
  'seating',
  'seats',
  'seaward',
  'seawater',
  'seaweed',
  'seconds',
  'secrecy',
  'secrets',
  'sect',
  'section',
  'sections',
  'sector',
  'sectors',
  'security',
  'sedan',
  'seed',
  'seeds',
  'seeming',
  'seers',
  'segment',
  'segments',
  'seine',
  'seizing',
  'seizure',
  'self',
  'seller',
  'semi',
  'seminar',
  'senator',
  'senior',
  'sense',
  'senses',
  'sensor',
  'sensors',
  'sentence',
  'sentinel',
  'sentries',
  'sentry',
  'sepia',
  'sequence',
  'serenity',
  'serfs',
  'sergeant',
  'series',
  'sermon',
  'serpent',
  'serpents',
  'servant',
  'servants',
  'server',
  'service',
  'services',
  'serving',
  'session',
  'sessions',
  'setback',
  'setting',
  'settings',
  'settling',
  'setup',
  'seven',
  'seventh',
  'seventy',
  'sewage',
  'sewing',
  'sex',
  'sexes',
  'shack',
  'shade',
  'shades',
  'shading',
  'shadow',
  'shadows',
  'shaft',
  'shafts',
  'sham',
  'shambles',
  'shame',
  'shan',
  'shard',
  'shards',
  'share',
  'shares',
  'shark',
  'sharks',
  'sharper',
  'shaving',
  'shavings',
  'shaw',
  'shawl',
  'shawls',
  'she',
  'shea',
  'sheaf',
  'sheath',
  'sheaths',
  'sheep',
  'sheet',
  'sheets',
  'shelf',
  'shell',
  'shells',
  'shelter',
  'shelves',
  'shepherd',
  'sheriff',
  'sherry',
  'shield',
  'shields',
  'shilling',
  'shin',
  'shins',
  'ship',
  'shipload',
  'shipment',
  'shipping',
  'ships',
  'shire',
  'shirt',
  'shirts',
  'shiver',
  'shivers',
  'shoals',
  'shock',
  'shocks',
  'shoe',
  'shoes',
  'shooter',
  'shop',
  'shoppers',
  'shops',
  'shore',
  'shores',
  'shortage',
  'shorts',
  'shot',
  'shots',
  'shoulder',
  'shovel',
  'shovels',
  'shower',
  'showers',
  'showing',
  'shred',
  'shreds',
  'shrimp',
  'shroud',
  'shutter',
  'shutters',
  'shuttle',
  'siblings',
  'sickness',
  'side',
  'sides',
  'sidewalk',
  'siege',
  'sifting',
  'sight',
  'sights',
  'sign',
  'signal',
  'signals',
  'signs',
  'silence',
  'silences',
  'silk',
  'silks',
  'sill',
  'silt',
  'silver',
  'simon',
  'sin',
  'sinews',
  'singer',
  'singers',
  'singsong',
  'sinner',
  'sins',
  'sinuses',
  'sir',
  'sire',
  'siren',
  'sirens',
  'sister',
  'sisters',
  'site',
  'sites',
  'sitting',
  'six',
  'sixpence',
  'sixteen',
  'sixth',
  'sixties',
  'sixty',
  'size',
  'sizes',
  'sizing',
  'skating',
  'skeleton',
  'sketch',
  'sketches',
  'skies',
  'skillet',
  'skimming',
  'skin',
  'skins',
  'skirmish',
  'skirt',
  'skirted',
  'skirting',
  'skirts',
  'skull',
  'skulls',
  'sky',
  'skyline',
  'slab',
  'slabs',
  'slam',
  'slap',
  'slaps',
  'slate',
  'slave',
  'slavery',
  'slaves',
  'sled',
  'sleep',
  'sleeper',
  'sleeps',
  'sleeve',
  'sleeved',
  'sleeves',
  'sleight',
  'slime',
  'slippers',
  'slit',
  'slits',
  'sliver',
  'slivers',
  'slop',
  'slot',
  'slug',
  'slum',
  'slur',
  'smack',
  'smallpox',
  'smash',
  'smashes',
  'smear',
  'smears',
  'smelt',
  'smith',
  'smiths',
  'smock',
  'smoke',
  'smokes',
  'smother',
  'snack',
  'snag',
  'snail',
  'snake',
  'snakes',
  'snapshot',
  'snare',
  'sneakers',
  'snot',
  'snout',
  'snow',
  'snuff',
  'soap',
  'soaring',
  'sob',
  'sobs',
  'society',
  'socket',
  'sockets',
  'socks',
  'sod',
  'soda',
  'sofa',
  'sojourn',
  'soldier',
  'soldiers',
  'sole',
  'solidity',
  'solitude',
  'solo',
  'solution',
  'somebody',
  'someone',
  'somewhat',
  'son',
  'song',
  'songs',
  'sooner',
  'soot',
  'sorcerer',
  'sorcery',
  'sores',
  'sorrow',
  'sorrows',
  'sort',
  'soul',
  'souls',
  'sounds',
  'soup',
  'source',
  'sources',
  'southern',
  'souvenir',
  'sow',
  'space',
  'spaces',
  'spade',
  'spades',
  'spain',
  'spaniard',
  'spanish',
  'spans',
  'spark',
  'sparks',
  'sparrow',
  'sparrows',
  'spartan',
  'spasm',
  'spasms',
  'speaker',
  'speakers',
  'spear',
  'spears',
  'species',
  'specimen',
  'speck',
  'specks',
  'specs',
  'specter',
  'specters',
  'spectre',
  'spectrum',
  'speech',
  'speeches',
  'speed',
  'speeds',
  'spelling',
  'spencer',
  'sphere',
  'spheres',
  'spice',
  'spices',
  'spider',
  'spiders',
  'spike',
  'spikes',
  'spindle',
  'spine',
  'spines',
  'spinning',
  'spirals',
  'spires',
  'spirit',
  'spirits',
  'spit',
  'spite',
  'spittle',
  'splat',
  'splendor',
  'splinter',
  'spoil',
  'spoils',
  'spokes',
  'sponge',
  'spoon',
  'spoonful',
  'spoons',
  'spot',
  'spots',
  'spouse',
  'spray',
  'sprig',
  'springs',
  'sprite',
  'spur',
  'squad',
  'squadron',
  'square',
  'squares',
  'squeaky',
  'squid',
  'squirrel',
  'stab',
  'stable',
  'stables',
  'stabs',
  'stack',
  'stacks',
  'staff',
  'stag',
  'stage',
  'stages',
  'stair',
  'stairs',
  'stairway',
  'stake',
  'stakes',
  'stalk',
  'stalked',
  'stalks',
  'stall',
  'stallion',
  'stalls',
  'stamina',
  'stance',
  'standard',
  'standby',
  'staple',
  'stapler',
  'star',
  'stars',
  'starters',
  'startup',
  'state',
  'states',
  'station',
  'stations',
  'stats',
  'statue',
  'statues',
  'stature',
  'status',
  'statutes',
  'stave',
  'stay',
  'stays',
  'stead',
  'stealth',
  'steam',
  'steel',
  'steeple',
  'steepled',
  'steer',
  'stem',
  'stems',
  'stench',
  'step',
  'stepped',
  'steps',
  'stew',
  'steward',
  'stewards',
  'stick',
  'stickers',
  'sticks',
  'stiletto',
  'stilts',
  'stimuli',
  'stirrup',
  'stirrups',
  'stock',
  'stocks',
  'stoic',
  'stomach',
  'stomachs',
  'stone',
  'stones',
  'stool',
  'stools',
  'storage',
  'stories',
  'stork',
  'storm',
  'storms',
  'story',
  'stove',
  'strain',
  'strains',
  'strand',
  'strands',
  'stranger',
  'strap',
  'straps',
  'strategy',
  'straw',
  'stray',
  'streak',
  'streaks',
  'stream',
  'streams',
  'street',
  'strength',
  'stress',
  'strife',
  'string',
  'strings',
  'stripe',
  'stripes',
  'stubble',
  'stucco',
  'stud',
  'student',
  'students',
  'studies',
  'studio',
  'studs',
  'study',
  'stuff',
  'stump',
  'stupor',
  'style',
  'styles',
  'styling',
  'sub',
  'subject',
  'subjects',
  'subtlety',
  'suburb',
  'suburbs',
  'success',
  'sucker',
  'suction',
  'suede',
  'sugar',
  'suicide',
  'suit',
  'suitcase',
  'suite',
  'suited',
  'suites',
  'suits',
  'sulfur',
  'sum',
  'summer',
  'summit',
  'summits',
  'summons',
  'sums',
  'sun',
  'sunday',
  'sundays',
  'sundown',
  'sunlight',
  'sunrise',
  'suns',
  'sunset',
  'sunshine',
  'supine',
  'supper',
  'surety',
  'surf',
  'surface',
  'surfaces',
  'surgeon',
  'surgery',
  'surmise',
  'surplus',
  'surprise',
  'survival',
  'suspects',
  'suspense',
  'swallow',
  'swallows',
  'swamp',
  'swan',
  'swarm',
  'swarms',
  'swat',
  'swatch',
  'swath',
  'swaths',
  'sway',
  'sweater',
  'sweaters',
  'sweeping',
  'sweetie',
  'sweets',
  'swelling',
  'swig',
  'swine',
  'swipe',
  'swiss',
  'switch',
  'switches',
  'swivel',
  'sword',
  'swords',
  'syllable',
  'symbol',
  'symbols',
  'symmetry',
  'sympathy',
  'symptoms',
  'syndrome',
  'syrup',
  'syrupy',
  'system',
  'systems',
  'tab',
  'table',
  'tableau',
  'tables',
  'tabletop',
  'tabs',
  'tackle',
  'tact',
  'tactic',
  'tactics',
  'tag',
  'tags',
  'tail',
  'tailor',
  'tails',
  'tale',
  'talent',
  'talented',
  'talents',
  'tales',
  'talisman',
  'tallow',
  'talon',
  'talons',
  'tang',
  'tank',
  'tanks',
  'tantrum',
  'tap',
  'tape',
  'taper',
  'tapers',
  'tapes',
  'tapestry',
  'tapping',
  'taps',
  'tar',
  'target',
  'targets',
  'task',
  'tasks',
  'tassels',
  'tasting',
  'tattoo',
  'tattoos',
  'taunt',
  'tavern',
  'taxi',
  'taylor',
  'tea',
  'teacher',
  'teaching',
  'team',
  'teams',
  'teapot',
  'tear',
  'tears',
  'teas',
  'teaser',
  'tech',
  'techs',
  'tedium',
  'tee',
  'telltale',
  'temerity',
  'tempest',
  'template',
  'temple',
  'temples',
  'tempter',
  'ten',
  'tenacity',
  'tenant',
  'tenants',
  'tendency',
  'tendril',
  'tendrils',
  'tennis',
  'tenor',
  'tens',
  'tense',
  'tension',
  'tent',
  'tentacle',
  'tenth',
  'tents',
  'term',
  'terminus',
  'terra',
  'terrace',
  'terraces',
  'terrain',
  'terrier',
  'terror',
  'terrors',
  'terry',
  'test',
  'tests',
  'tether',
  'text',
  'texts',
  'texture',
  'textured',
  'thanks',
  'that',
  'theater',
  'theatre',
  'thee',
  'theft',
  'them',
  'theme',
  'themes',
  'theology',
  'theories',
  'theory',
  'therapy',
  'thermals',
  'thesis',
  'thicket',
  'thief',
  'thigh',
  'thighs',
  'thing',
  'things',
  'thinking',
  'thinner',
  'thirds',
  'thirst',
  'thirteen',
  'thirties',
  'thirty',
  'this',
  'thomas',
  'thorn',
  'thorns',
  'thou',
  'thoughts',
  'thousand',
  'thrall',
  'thread',
  'threads',
  'threat',
  'threats',
  'three',
  'threes',
  'thrift',
  'throat',
  'throes',
  'throne',
  'throng',
  'throngs',
  'thrum',
  'thud',
  'thuds',
  'thumb',
  'thunder',
  'thursday',
  'tic',
  'tick',
  'ticket',
  'tickets',
  'ticking',
  'ticks',
  'tide',
  'tides',
  'tidings',
  'tie',
  'ties',
  'tiger',
  'tile',
  'tilt',
  'timber',
  'timbre',
  'time',
  'timer',
  'timing',
  'tin',
  'tinder',
  'tinged',
  'tint',
  'tints',
  'tiptoe',
  'tiptoes',
  'tirade',
  'tis',
  'tissue',
  'tissues',
  'title',
  'titles',
  'toad',
  'toads',
  'tobacco',
  'toddler',
  'toe',
  'toes',
  'toil',
  'toilet',
  'token',
  'tokens',
  'toll',
  'tolls',
  'tom',
  'tomato',
  'tomb',
  'tome',
  'tomes',
  'tone',
  'tones',
  'tongs',
  'tongue',
  'tongues',
  'tons',
  'tony',
  'tool',
  'tools',
  'tooth',
  'top',
  'topaz',
  'topic',
  'topics',
  'topped',
  'tor',
  'torch',
  'torches',
  'torment',
  'torments',
  'tornado',
  'torpor',
  'torrent',
  'torrents',
  'torso',
  'tortoise',
  'torture',
  'tortures',
  'totem',
  'tour',
  'tourist',
  'tourists',
  'tours',
  'towel',
  'towels',
  'tower',
  'towered',
  'towers',
  'town',
  'towns',
  'toy',
  'toys',
  'trace',
  'traces',
  'tracing',
  'track',
  'tracking',
  'tracks',
  'traction',
  'trade',
  'traders',
  'trades',
  'traffic',
  'tragedy',
  'train',
  'training',
  'trains',
  'traitor',
  'traitors',
  'traits',
  'trance',
  'transit',
  'trap',
  'trapdoor',
  'traps',
  'trash',
  'trauma',
  'traveler',
  'traverse',
  'tray',
  'trays',
  'treason',
  'treasure',
  'treatise',
  'tree',
  'trees',
  'treetops',
  'trellis',
  'tremor',
  'tremors',
  'trench',
  'trenches',
  'trial',
  'trials',
  'triangle',
  'tribe',
  'tribes',
  'tribunal',
  'tribute',
  'trick',
  'trickery',
  'tricks',
  'trident',
  'trifle',
  'trigger',
  'triggers',
  'trimming',
  'trinkets',
  'trio',
  'tripod',
  'triumph',
  'triumphs',
  'trivia',
  'trolley',
  'troop',
  'troops',
  'trophy',
  'trot',
  'trough',
  'troughs',
  'troupe',
  'trouser',
  'trousers',
  'trove',
  'truce',
  'trump',
  'trumpet',
  'trunk',
  'trunks',
  'trust',
  'trustees',
  'trusts',
  'truth',
  'tub',
  'tube',
  'tubes',
  'tuesday',
  'tufts',
  'tumbler',
  'tumblers',
  'tumbling',
  'tumult',
  'tune',
  'tunes',
  'tunic',
  'tunnel',
  'tunnels',
  'turban',
  'turbaned',
  'turf',
  'turkey',
  'turmoil',
  'turning',
  'turnings',
  'turnover',
  'turrets',
  'turtle',
  'turtles',
  'tutor',
  'twelfth',
  'twelve',
  'twenties',
  'twenty',
  'twig',
  'twigs',
  'twilight',
  'twin',
  'twine',
  'twins',
  'twisting',
  'twitchy',
  'twopence',
  'twos',
  'type',
  'types',
  'tyranny',
  'tyrants',
  'uke',
  'umbrella',
  'uncle',
  'uncles',
  'undead',
  'undoing',
  'unease',
  'unicorn',
  'union',
  'unison',
  'unit',
  'units',
  'unity',
  'universe',
  'unrest',
  'upgrades',
  'uproar',
  'upside',
  'urchin',
  'urgency',
  'urine',
  'usage',
  'use',
  'user',
  'users',
  'utensils',
  'utility',
  'vacancy',
  'vacation',
  'vacuum',
  'vale',
  'valet',
  'valley',
  'valleys',
  'valor',
  'value',
  'values',
  'valve',
  'valves',
  'vampire',
  'vampires',
  'van',
  'vandals',
  'vanes',
  'vanguard',
  'vanilla',
  'vanity',
  'vantage',
  'vapor',
  'vapors',
  'variety',
  'vase',
  'vases',
  'vats',
  'vault',
  'vaults',
  'veal',
  'vee',
  'vehicle',
  'vehicles',
  'veil',
  'veils',
  'vein',
  'veins',
  'velocity',
  'velvet',
  'vendor',
  'vendors',
  'veneer',
  'venison',
  'venom',
  'venus',
  'veranda',
  'verb',
  'verdict',
  'verge',
  'vermin',
  'verse',
  'verses',
  'version',
  'versions',
  'vertigo',
  'vessel',
  'vessels',
  'vestige',
  'vet',
  'veteran',
  'veterans',
  'vial',
  'vials',
  'vice',
  'vices',
  'vicinity',
  'victim',
  'victims',
  'victor',
  'victoria',
  'victory',
  'video',
  'videos',
  'viejo',
  'view',
  'viewer',
  'viewers',
  'viewing',
  'views',
  'vigil',
  'vigor',
  'vii',
  'viii',
  'village',
  'villages',
  'villain',
  'villains',
  'vine',
  'vinegar',
  'vines',
  'vintage',
  'violence',
  'violet',
  'violin',
  'viper',
  'vipers',
  'virgin',
  'virgins',
  'virtue',
  'virtues',
  'virus',
  'visage',
  'visages',
  'vise',
  'vision',
  'visions',
  'visitor',
  'visor',
  'vista',
  'vitality',
  'vocation',
  'voice',
  'voices',
  'volcano',
  'volition',
  'volley',
  'volleys',
  'voltage',
  'volume',
  'volumes',
  'vomit',
  'vortex',
  'vote',
  'votes',
  'vow',
  'vows',
  'voyage',
  'voyeur',
  'vultures',
  'wad',
  'wafer',
  'wage',
  'wager',
  'wages',
  'wagon',
  'wagons',
  'waist',
  'waiter',
  'waitress',
  'wales',
  'walking',
  'walkway',
  'walkways',
  'wall',
  'wallet',
  'walls',
  'walnut',
  'walter',
  'waltz',
  'wan',
  'wand',
  'war',
  'ward',
  'wardrobe',
  'wards',
  'warfare',
  'warheads',
  'warmer',
  'warmth',
  'warning',
  'warnings',
  'warp',
  'warrant',
  'warranty',
  'warren',
  'warrens',
  'warrior',
  'warriors',
  'wars',
  'warship',
  'washing',
  'wasp',
  'wasps',
  'waste',
  'watchers',
  'watchman',
  'watchmen',
  'water',
  'waters',
  'wave',
  'waves',
  'wax',
  'waxes',
  'way',
  'wayside',
  'weakness',
  'wealth',
  'weapon',
  'weaponry',
  'weapons',
  'weather',
  'weaver',
  'web',
  'webbed',
  'webs',
  'wedding',
  'wedge',
  'weed',
  'weeds',
  'week',
  'weekend',
  'weeks',
  'weight',
  'weights',
  'weird',
  'welfare',
  'well',
  'wells',
  'welts',
  'whale',
  'whales',
  'wharf',
  'what',
  'whatever',
  'wheat',
  'wheel',
  'wheeling',
  'wheels',
  'whether',
  'whew',
  'whiff',
  'while',
  'whim',
  'whims',
  'whiny',
  'whipping',
  'whisk',
  'whiskers',
  'whistle',
  'whistles',
  'whites',
  'who',
  'whoever',
  'whom',
  'whomever',
  'whoosh',
  'whore',
  'wick',
  'wicker',
  'wicks',
  'widow',
  'widows',
  'width',
  'wife',
  'wig',
  'william',
  'williams',
  'willow',
  'willows',
  'winches',
  'wind',
  'winding',
  'window',
  'windows',
  'winds',
  'wine',
  'wines',
  'wing',
  'wings',
  'winning',
  'winter',
  'winters',
  'wire',
  'wires',
  'wiring',
  'wisdom',
  'wise',
  'wisp',
  'wisps',
  'wispy',
  'witch',
  'witches',
  'witness',
  'wits',
  'wizard',
  'wobbly',
  'wolf',
  'wolves',
  'woman',
  'womb',
  'women',
  'wonder',
  'wonders',
  'woodpile',
  'woods',
  'wool',
  'word',
  'wording',
  'work',
  'worker',
  'workers',
  'working',
  'workings',
  'workmen',
  'workout',
  'workroom',
  'workshop',
  'world',
  'worlds',
  'worm',
  'worms',
  'worship',
  'worships',
  'wound',
  'wounded',
  'wounds',
  'wraith',
  'wrapper',
  'wrappers',
  'wrapping',
  'wrath',
  'wreath',
  'wreaths',
  'wreck',
  'wreckage',
  'wretches',
  'wrinkle',
  'wrinkles',
  'wrist',
  'wrists',
  'writer',
  'writing',
  'writings',
  'wrong',
  'wrongs',
  'xii',
  'yank',
  'yankee',
  'yard',
  'yards',
  'yaw',
  'year',
  'yearning',
  'years',
  'yellows',
  'yelp',
  'york',
  'you',
  'younger',
  'youngest',
  'yourself',
  'youth',
  'youths',
  'zeal',
  'zealot',
  'zenith',
  'zero',
  'zeus',
  'zigzag',
  'zombie',
  'zombies',
  'zone',
  'zones',
  'zoo'
]
verbs = [
  'abandoned',
  'abashed',
  'abated',
  'abducted',
  'abide',
  'aborted',
  'absorbed',
  'abused',
  'accented',
  'accept',
  'accepts',
  'accessed',
  'accorded',
  'accosted',
  'accused',
  'accustom',
  'ached',
  'aches',
  'achieve',
  'acquired',
  'acted',
  'activate',
  'adapted',
  'added',
  'addicted',
  'addressed',
  'adjust',
  'admired',
  'admirer',
  'admitted',
  'adopted',
  'adored',
  'adorned',
  'advance',
  'advances',
  'advised',
  'afforded',
  'affronted',
  'agitated',
  'agreed',
  'agreeed',
  'aid',
  'ailed',
  'aimed',
  'alarmed',
  'alerted',
  'alighted',
  'aligned',
  'allowed',
  'allured',
  'allyed',
  'altered',
  'amazed',
  'ambled',
  'ambushed',
  'amended',
  'amused',
  'analyzed',
  'anchored',
  'angered',
  'announced',
  'annoyed',
  'answered',
  'appalled',
  'appealed',
  'appeared',
  'appeased',
  'appended',
  'applauded',
  'applied',
  'apprised',
  'approached',
  'approved',
  'arced',
  'arched',
  'argued',
  'armed',
  'arose',
  'aroused',
  'arranged',
  'arrayed',
  'arrested',
  'arrived',
  'arrowed',
  'ascended',
  'ashed',
  'asked',
  'aspired',
  'assemble',
  'assent',
  'asserted',
  'assessed',
  'assigned',
  'assisted',
  'assumed',
  'assured',
  'assures',
  'astonish',
  'attach',
  'attacked',
  'attacker',
  'attained',
  'attempt',
  'attempts',
  'attended',
  'attire',
  'attract',
  'attuned',
  'augment',
  'avail',
  'avenged',
  'averted',
  'avoided',
  'avow',
  'awaited',
  'awake',
  'awakened',
  'award',
  'awards',
  'babbled',
  'baffled',
  'bagged',
  'baited',
  'baked',
  'balked',
  'balled',
  'ban',
  'bandaged',
  'banged',
  'banished',
  'banked',
  'banned',
  'banter',
  'bared',
  'barked',
  'barter',
  'basked',
  'bathed',
  'batted',
  'battered',
  'battled',
  'bawled',
  'beaded',
  'beamed',
  'beat',
  'beats',
  'became',
  'beckoned',
  'become',
  'becomes',
  'beeped',
  'befall',
  'befallen',
  'beg',
  'began',
  'begged',
  'begin',
  'begins',
  'begone',
  'begun',
  'behaved',
  'behaves',
  'beheaded',
  'beheld',
  'behold',
  'belched',
  'belied',
  'believed',
  'believer',
  'believes',
  'bellowed',
  'belonged',
  'bemused',
  'bended',
  'beseech',
  'besieged',
  'bested',
  'bestowed',
  'betrayal',
  'betrayed',
  'betted',
  'beware',
  'bidded',
  'bidden',
  'bided',
  'billowed',
  'bind',
  'bite',
  'bites',
  'bitten',
  'blacked',
  'blamed',
  'blanched',
  'blanked',
  'blared',
  'blasted',
  'blazed',
  'bleached',
  'bleated',
  'bled',
  'bleed',
  'bleeds',
  'blended',
  'bless',
  'blinded',
  'blinked',
  'blockade',
  'blocked',
  'bloodied',
  'bloomed',
  'blotch',
  'blotted',
  'blowed',
  'blurred',
  'blurted',
  'blushed',
  'bluster',
  'boarded',
  'boasted',
  'bob',
  'bobbed',
  'boiled',
  'bolted',
  'booked',
  'boomed',
  'boosted',
  'booted',
  'bored',
  'bores',
  'borrowed',
  'botched',
  'bothered',
  'bottled',
  'bounced',
  'bounded',
  'bow',
  'bows',
  'braced',
  'braces',
  'braid',
  'braids',
  'braked',
  'braved',
  'brawled',
  'breached',
  'breaked',
  'breathe',
  'bred',
  'breed',
  'breeds',
  'breezed',
  'brewed',
  'bribed',
  'bridged',
  'briefed',
  'brighten',
  'brimmed',
  'bringed',
  'bristled',
  'broached',
  'bronze',
  'brooded',
  'bruised',
  'bruises',
  'brushed',
  'bubbled',
  'bucked',
  'buckled',
  'budded',
  'buffeted',
  'bugged',
  'build',
  'builds',
  'bulged',
  'bullyed',
  'bumped',
  'bunched',
  'bundled',
  'burdened',
  'buried',
  'burned',
  'burnt',
  'burrowed',
  'bursted',
  'buryed',
  'busied',
  'busted',
  'bustled',
  'butted',
  'buttered',
  'buttoned',
  'buyed',
  'buzzed',
  'cackled',
  'caged',
  'caked',
  'call',
  'calls',
  'callused',
  'calmed',
  'camped',
  'canceled',
  'canned',
  'cans',
  'canted',
  'cantered',
  'capped',
  'captured',
  'card',
  'cards',
  'cared',
  'careened',
  'caressed',
  'caresses',
  'carried',
  'carries',
  'carryed',
  'carted',
  'carved',
  'cascaded',
  'cast',
  'catch',
  'catches',
  'caused',
  'ceased',
  'chafed',
  'chained',
  'chalked',
  'chanced',
  'changed',
  'changes',
  'chanted',
  'charged',
  'charred',
  'charted',
  'chased',
  'chastise',
  'chat',
  'chatted',
  'chatter',
  'cheated',
  'checked',
  'cheered',
  'chewed',
  'chided',
  'chilled',
  'chimed',
  'chinked',
  'chipped',
  'chirped',
  'choked',
  'choosed',
  'chooses',
  'chop',
  'chopped',
  'chortled',
  'chucked',
  'chuckled',
  'churned',
  'cinched',
  'circled',
  'cited',
  'clacked',
  'claimed',
  'clamber',
  'clamped',
  'clanged',
  'clanked',
  'clap',
  'clapped',
  'clarify',
  'clashed',
  'clasped',
  'clatter',
  'clawed',
  'cleaned',
  'cleared',
  'cled',
  'clenched',
  'clicked',
  'climbed',
  'clinged',
  'clinked',
  'clip',
  'clipped',
  'cloaked',
  'clogged',
  'close',
  'closes',
  'clothed',
  'clouded',
  'clucked',
  'clunk',
  'clutched',
  'clutches',
  'clutter',
  'coasted',
  'coaxed',
  'cocked',
  'coded',
  'coiled',
  'collapse',
  'collided',
  'combine',
  'come',
  'comes',
  'comfort',
  'comforts',
  'command',
  'commands',
  'commence',
  'commend',
  'commit',
  'commune',
  'compared',
  'compass',
  'compel',
  'compete',
  'compiled',
  'complain',
  'complied',
  'comply',
  'compose',
  'compound',
  'compress',
  'con',
  'conceal',
  'conceded',
  'conceive',
  'concern',
  'concerns',
  'conclude',
  'condemned',
  'confer',
  'confess',
  'confide',
  'confirm',
  'confirms',
  'conform',
  'confront',
  'confuse',
  'confuses',
  'conjured',
  'connect',
  'conquer',
  'consent',
  'conserve',
  'consider',
  'consist',
  'consists',
  'consoled',
  'consult',
  'consumed',
  'contain',
  'contains',
  'contend',
  'contents',
  'contest',
  'continue',
  'contrast',
  'contrive',
  'control',
  'controls',
  'converge',
  'convert',
  'converts',
  'conveyed',
  'convince',
  'convoy',
  'cooed',
  'cooked',
  'cooled',
  'copied',
  'copyed',
  'correct',
  'corrupt',
  'costed',
  'couch',
  'couches',
  'coughed',
  'counted',
  'coup',
  'coupled',
  'coursed',
  'courted',
  'covered',
  'coveted',
  'cowed',
  'cowered',
  'crack',
  'crackled',
  'cracks',
  'cradled',
  'crafted',
  'cram',
  'crammed',
  'cramped',
  'craned',
  'cranked',
  'crashed',
  'crashes',
  'craved',
  'crawled',
  'crazed',
  'creaked',
  'creased',
  'created',
  'creep',
  'creeps',
  'crewed',
  'cried',
  'cries',
  'cringed',
  'crinkled',
  'crippled',
  'croaked',
  'crook',
  'crooks',
  'cropped',
  'crossed',
  'crouched',
  'crowded',
  'crowed',
  'crowned',
  'cruised',
  'crumbled',
  'crumpled',
  'crunched',
  'crushed',
  'cry',
  'cuddled',
  'cuffed',
  'cupped',
  'cured',
  'curled',
  'curry',
  'cursed',
  'curtsied',
  'curved',
  'cut',
  'cuts',
  'cycled',
  'dabbed',
  'damaged',
  'damn',
  'dampened',
  'danced',
  'dancer',
  'dancers',
  'dances',
  'dangled',
  'dared',
  'dares',
  'daresay',
  'darkened',
  'darted',
  'dash',
  'dashes',
  'dated',
  'dawdled',
  'dawned',
  'dazed',
  'dazzled',
  'deadened',
  'deafened',
  'dealer',
  'dealt',
  'debated',
  'decayed',
  'deceived',
  'decide',
  'decides',
  'decipher',
  'decked',
  'declared',
  'declined',
  'decorate',
  'decrease',
  'decreed',
  'ded',
  'deduced',
  'deemed',
  'deepened',
  'defaced',
  'defeated',
  'defended',
  'defined',
  'defines',
  'deflated',
  'defyed',
  'deign',
  'delayed',
  'deleted',
  'deliver',
  'deluded',
  'delved',
  'demanded',
  'demise',
  'denied',
  'denies',
  'denoted',
  'denounce',
  'dented',
  'denyed',
  'depart',
  'depended',
  'depicted',
  'depleted',
  'deployed',
  'deposit',
  'deprive',
  'deranged',
  'derive',
  'descended',
  'describe',
  'deserted',
  'deserve',
  'deserves',
  'designed',
  'desired',
  'desires',
  'despair',
  'despised',
  'destined',
  'destroy',
  'destroys',
  'detach',
  'detained',
  'detected',
  'detested',
  'detonate',
  'detract',
  'develop',
  'devised',
  'devote',
  'devoured',
  'dictated',
  'died',
  'dies',
  'differ',
  'diffused',
  'dig',
  'digged',
  'diluted',
  'diminish',
  'dimmed',
  'dimpled',
  'dined',
  'dip',
  'dipped',
  'direct',
  'disable',
  'disagree',
  'disarmed',
  'discern',
  'disclosed',
  'discover',
  'discuss',
  'disgrace',
  'disguise',
  'disliked',
  'dislodge',
  'dismayed',
  'dismissed',
  'dismount',
  'disobey',
  'disorder',
  'dispatch',
  'dispel',
  'dispense',
  'disperse',
  'display',
  'displays',
  'disposed',
  'disputed',
  'disputes',
  'disquieted',
  'disrupt',
  'dissolve',
  'distaste',
  'distort',
  'disturb',
  'disturbs',
  'dived',
  'diverted',
  'divided',
  'divorced',
  'dizzyed',
  'docked',
  'dodged',
  'doffed',
  'dogged',
  'doin',
  'domed',
  'dominate',
  'donate',
  'doned',
  'donned',
  'doomed',
  'dotted',
  'doubled',
  'doubted',
  'doused',
  'downed',
  'dozed',
  'dragged',
  'drained',
  'draped',
  'drapes',
  'draw',
  'drawled',
  'draws',
  'dreaded',
  'dreamed',
  'dreamt',
  'dredge',
  'drenched',
  'dressed',
  'dresses',
  'dried',
  'drifted',
  'drilled',
  'drinked',
  'drip',
  'dripped',
  'drive',
  'drives',
  'droned',
  'drooled',
  'drooped',
  'drowned',
  'drummed',
  'dryed',
  'dubbed',
  'ducked',
  'dueled',
  'dulled',
  'dumped',
  'dunked',
  'duped',
  'dusted',
  'dwarfed',
  'dwelled',
  'dwelt',
  'dwindled',
  'dyed',
  'eagled',
  'earned',
  'ears',
  'eased',
  'eat',
  'eaten',
  'eaters',
  'eats',
  'ebbed',
  'echoed',
  'eddied',
  'edited',
  'educate',
  'egg',
  'eggs',
  'eject',
  'elapsed',
  'elbowed',
  'elected',
  'elicited',
  'eluded',
  'embark',
  'embraced',
  'embraces',
  'emerged',
  'emerges',
  'emits',
  'emitted',
  'employed',
  'employer',
  'emptied',
  'empties',
  'emptyed',
  'enabled',
  'enables',
  'enameled',
  'enamored',
  'enclosed',
  'endanger',
  'endeavor',
  'endowed',
  'endured',
  'enfolded',
  'enforced',
  'engage',
  'engraved',
  'engulfed',
  'enhanced',
  'enjoyed',
  'enlarged',
  'enraged',
  'enslaved',
  'ensnared',
  'ensued',
  'ensured',
  'entered',
  'enticed',
  'entitled',
  'entreat',
  'entrust',
  'envelop',
  'envied',
  'equipped',
  'erased',
  'erected',
  'erupted',
  'escaped',
  'escapes',
  'escorted',
  'essay',
  'esteemed',
  'estimated',
  'etched',
  'evacuate',
  'evaded',
  'evaluate',
  'evoked',
  'evolved',
  'exacted',
  'exalted',
  'examined',
  'exceeded',
  'excel',
  'excepted',
  'excerpt',
  'excited',
  'exclaim',
  'excluded',
  'excused',
  'executed',
  'exerted',
  'exhaled',
  'exhaust',
  'exhibit',
  'exiled',
  'existed',
  'exited',
  'expand',
  'expected',
  'expelled',
  'expended',
  'expired',
  'explain',
  'explains',
  'exploded',
  'explored',
  'export',
  'exposed',
  'extend',
  'extends',
  'extract',
  'exuded',
  'eyeed',
  'faced',
  'faded',
  'failed',
  'fainted',
  'faked',
  'falled',
  'fallen',
  'faltered',
  'fancied',
  'fancies',
  'fancy',
  'fanned',
  'fared',
  'fasted',
  'fastened',
  'fatigued',
  'feared',
  'feasted',
  'fed',
  'feed',
  'feeds',
  'feel',
  'feels',
  'feigned',
  'felled',
  'fenced',
  'fend',
  'ferry',
  'fetched',
  'fighted',
  'figured',
  'filed',
  'filled',
  'filtered',
  'find',
  'finds',
  'finished',
  'fished',
  'fix',
  'flailed',
  'flanked',
  'flapped',
  'flashed',
  'flashes',
  'flattered',
  'fled',
  'fleeed',
  'fleet',
  'flexed',
  'flicked',
  'flicker',
  'flickers',
  'flies',
  'flinched',
  'flinged',
  'flipped',
  'flirt',
  'floated',
  'flocked',
  'flooded',
  'flourish',
  'flowed',
  'flushed',
  'flutter',
  'fly',
  'foamed',
  'focused',
  'fogged',
  'foil',
  'foisted',
  'folded',
  'followed',
  'fooled',
  'foraged',
  'forbade',
  'forbear',
  'forbid',
  'forced',
  'forearm',
  'forearms',
  'foresee',
  'foreseen',
  'forgave',
  'forged',
  'forget',
  'forgets',
  'forgive',
  'forgiven',
  'forgot',
  'formed',
  'forsaken',
  'fortify',
  'fostered',
  'founded',
  'framed',
  'frames',
  'frayed',
  'freckled',
  'freed',
  'freeed',
  'freezed',
  'frequent',
  'fretted',
  'fries',
  'frighten',
  'frills',
  'fringed',
  'frothed',
  'frowned',
  'fryed',
  'fueled',
  'fumbled',
  'fumed',
  'funded',
  'fur',
  'furled',
  'furnish',
  'furrowed',
  'fused',
  'fussed',
  'gag',
  'gagged',
  'gained',
  'gainsay',
  'galloped',
  'gambled',
  'gang',
  'gangs',
  'gaped',
  'garbled',
  'gardener',
  'gargle',
  'garnered',
  'gasped',
  'gathered',
  'gauged',
  'gave',
  'gawked',
  'gazed',
  'gazes',
  'gee',
  'generate',
  'gestured',
  'get',
  'getted',
  'ghosted',
  'giggled',
  'giggles',
  'gilded',
  'gin',
  'girded',
  'give',
  'gives',
  'glanced',
  'glances',
  'glared',
  'gleamed',
  'gleaned',
  'glided',
  'glimmer',
  'glimpsed',
  'glimpses',
  'glinted',
  'glitter',
  'gloat',
  'gloom',
  'gloved',
  'glowed',
  'glowered',
  'glued',
  'gnashed',
  'gnawed',
  'goaded',
  'gobbled',
  'goin',
  'gouged',
  'governed',
  'grab',
  'grabbed',
  'grabs',
  'graced',
  'granted',
  'grasped',
  'grated',
  'grave',
  'graveled',
  'grayed',
  'grazed',
  'greens',
  'greeted',
  'grieved',
  'grilled',
  'grinded',
  'grinned',
  'grins',
  'grip',
  'gripped',
  'grips',
  'gritted',
  'groaned',
  'groomed',
  'groped',
  'grouped',
  'growed',
  'growled',
  'grub',
  'grubbed',
  'grudge',
  'grudges',
  'grumbled',
  'grunted',
  'guarded',
  'guessed',
  'guesses',
  'guided',
  'gulped',
  'gurgled',
  'gushed',
  'gusted',
  'gutted',
  'hackeded',
  'hailed',
  'halted',
  'hamper',
  'handed',
  'hanged',
  'happened',
  'harass',
  'harbored',
  'hardened',
  'hark',
  'harmed',
  'harry',
  'hashed',
  'hastened',
  'hatched',
  'hated',
  'hauled',
  'haunted',
  'haved',
  'hazarded',
  'healed',
  'heaped',
  'heard',
  'hears',
  'heated',
  'heaved',
  'heed',
  'heeled',
  'hefted',
  'heighten',
  'helped',
  'hemmed',
  'herded',
  'hesitate',
  'hewn',
  'hided',
  'hiked',
  'hinged',
  'hinted',
  'hired',
  'hissed',
  'hit',
  'hitched',
  'hits',
  'hobbled',
  'hoisted',
  'hold',
  'holds',
  'holed',
  'hollered',
  'hollowed',
  'homed',
  'honed',
  'honored',
  'hoots',
  'hoped',
  'hopes',
  'hopped',
  'hosted',
  'housed',
  'hovered',
  'howled',
  'huddled',
  'huffed',
  'hug',
  'hugged',
  'hum',
  'humbled',
  'hummed',
  'hunched',
  'hunkered',
  'hunted',
  'hurled',
  'hurryed',
  'hurted',
  'hurtled',
  'hushed',
  'hustled',
  'iced',
  'identified',
  'idled',
  'ids',
  'ignited',
  'ignored',
  'imagined',
  'imitated',
  'immersed',
  'impact',
  'impacts',
  'impaled',
  'imparted',
  'impelled',
  'implants',
  'implied',
  'implies',
  'implored',
  'implyed',
  'imported',
  'imposed',
  'impress',
  'imprint',
  'imprison',
  'improved',
  'improves',
  'impulse',
  'impulses',
  'inched',
  'incline',
  'included',
  'includes',
  'increase',
  'indicate',
  'induced',
  'indulged',
  'infected',
  'inferred',
  'infested',
  'inflict',
  'informed',
  'infused',
  'inhabit',
  'inhaled',
  'inherit',
  'initiated',
  'injected',
  'injured',
  'inquired',
  'inserted',
  'insisted',
  'inspect',
  'inspire',
  'install',
  'instruct',
  'insulted',
  'intend',
  'intends',
  'inter',
  'interact',
  'intimate',
  'intoned',
  'intrude',
  'intruder',
  'invaded',
  'invader',
  'invaders',
  'invented',
  'inverted',
  'invested',
  'invited',
  'invoked',
  'involved',
  'involves',
  'ironed',
  'isolate',
  'issued',
  'itched',
  'jab',
  'jabbed',
  'jabs',
  'jam',
  'jammed',
  'jangled',
  'jar',
  'jarred',
  'jars',
  'jeered',
  'jerked',
  'jeweled',
  'jiggled',
  'jingled',
  'jog',
  'jogged',
  'joined',
  'joked',
  'jolted',
  'jostled',
  'judged',
  'juggled',
  'jumbled',
  'jumped',
  'justify',
  'jutted',
  'keel',
  'keened',
  'keeps',
  'ken',
  'kept',
  'kicked',
  'kidded',
  'kidnap',
  'kill',
  'kills',
  'kindled',
  'kissed',
  'kisses',
  'kneeled',
  'knelt',
  'knit',
  'knitted',
  'knocked',
  'knotted',
  'know',
  'knows',
  'labeled',
  'labored',
  'laced',
  'laces',
  'lacked',
  'laden',
  'lanced',
  'lapped',
  'lashed',
  'lashes',
  'lasted',
  'latched',
  'latches',
  'laughed',
  'launched',
  'layed',
  'leaded',
  'leaked',
  'leaned',
  'leaped',
  'leapt',
  'learned',
  'leaved',
  'lectured',
  'leered',
  'lended',
  'lessened',
  'let',
  'letted',
  'leveled',
  'levered',
  'licked',
  'lied',
  'lifted',
  'lighted',
  'lighten',
  'liked',
  'likes',
  'limped',
  'lined',
  'lingered',
  'linked',
  'listed',
  'listened',
  'listener',
  'littered',
  'lived',
  'loathed',
  'located',
  'locked',
  'lodged',
  'lofted',
  'logged',
  'loitered',
  'lolled',
  'longed',
  'looked',
  'loomed',
  'loosed',
  'loosened',
  'looted',
  'loped',
  'lopped',
  'lose',
  'loses',
  'lounged',
  'loved',
  'low',
  'lowered',
  'lulled',
  'lumbered',
  'lurched',
  'lurches',
  'lured',
  'lurked',
  'mailed',
  'maimed',
  'maintained',
  'made',
  'managed',
  'manages',
  'mangled',
  'mapped',
  'mar',
  'marched',
  'marooned',
  'marred',
  'marryed',
  'martyred',
  'marveled',
  'mashed',
  'masked',
  'massed',
  'mastered',
  'matched',
  'mated',
  'matted',
  'mattered',
  'matured',
  'maze',
  'mean',
  'means',
  'meant',
  'meddled',
  'meet',
  'meets',
  'melded',
  'melted',
  'memorized',
  'menaced',
  'mended',
  'merged',
  'messed',
  'miffed',
  'milled',
  'mimicked',
  'minded',
  'mined',
  'miner',
  'miners',
  'mingled',
  'minimize',
  'misled',
  'missed',
  'misses',
  'mistake',
  'mistaken',
  'mistakes',
  'misused',
  'mixed',
  'moaned',
  'mobbed',
  'mocked',
  'modified',
  'molded',
  'motioned',
  'mounded',
  'mounted',
  'mourned',
  'moved',
  'moves',
  'mown',
  'mrs',
  'muddle',
  'muffled',
  'mulled',
  'mumbled',
  'mumbles',
  'munched',
  'murdered',
  'murmured',
  'mused',
  'must',
  'mustered',
  'muttered',
  'nagged',
  'nailed',
  'named',
  'nap',
  'narrated',
  'narrowed',
  'navigate',
  'neared',
  'needed',
  'neglect',
  'neglects',
  'nested',
  'nestled',
  'netted',
  'nibbled',
  'nipped',
  'nod',
  'nodded',
  'nods',
  'noted',
  'notes',
  'noticed',
  'notified',
  'notify',
  'nudged',
  'numbered',
  'nursed',
  'nurtured',
  'nuzzled',
  'obeyed',
  'objected',
  'obliged',
  'obscured',
  'observed',
  'obsessed',
  'obtained',
  'occupied',
  'occupy',
  'occur',
  'occurred',
  'occurs',
  'offended',
  'offered',
  'offs',
  'ogled',
  'omitted',
  'oozed',
  'opened',
  'operated',
  'opposed',
  'opted',
  'orbited',
  'ordained',
  'ordered',
  'organize',
  'orphaned',
  'outdone',
  'outlined',
  'outraged',
  'outrun',
  'outs',
  'overcame',
  'overcome',
  'overdo',
  'overhang',
  'overhear',
  'overlaid',
  'overlook',
  'override',
  'overrun',
  'oversee',
  'overseen',
  'overtake',
  'overtook',
  'owed',
  'owes',
  'owned',
  'owner',
  'owners',
  'paced',
  'pad',
  'padded',
  'pads',
  'paged',
  'painted',
  'paled',
  'pampered',
  'paneled',
  'panicked',
  'panted',
  'paraded',
  'pardoned',
  'parked',
  'parquet',
  'parried',
  'parry',
  'partake',
  'passed',
  'passers',
  'passes',
  'pasted',
  'patched',
  'patted',
  'pattered',
  'paused',
  'pawed',
  'payed',
  'pecked',
  'peeked',
  'peeled',
  'peeped',
  'peered',
  'pelted',
  'pen',
  'penned',
  'pens',
  'peopled',
  'peppered',
  'perceive',
  'perched',
  'perform',
  'perfumed',
  'perished',
  'perked',
  'permeated',
  'permit',
  'permits',
  'persist',
  'persuade',
  'perusal',
  'peruse',
  'pervaded',
  'pervert',
  'petered',
  'petted',
  'phrased',
  'picked',
  'pictured',
  'pierce',
  'pill',
  'piloted',
  'pinched',
  'pined',
  'pinned',
  'piped',
  'piqued',
  'pissed',
  'pitched',
  'pitied',
  'pivoted',
  'placed',
  'plagued',
  'plain',
  'planed',
  'planes',
  'planned',
  'planted',
  'plated',
  'played',
  'pleaded',
  'pleased',
  'pleases',
  'pledged',
  'plied',
  'plight',
  'plodded',
  'plop',
  'plopped',
  'plotted',
  'ploughed',
  'plowed',
  'plucked',
  'plump',
  'plunder',
  'plunged',
  'plunges',
  'pocketed',
  'pointed',
  'poise',
  'poisoned',
  'poked',
  'police',
  'polished',
  'polluted',
  'pondered',
  'pooled',
  'pop',
  'popped',
  'pops',
  'pored',
  'portray',
  'posed',
  'poses',
  'possess',
  'posted',
  'postpone',
  'pounced',
  'pounded',
  'poured',
  'pouted',
  'powdered',
  'powered',
  'practice',
  'praised',
  'praises',
  'pranced',
  'prayed',
  'preach',
  'preacher',
  'preceded',
  'predated',
  'predict',
  'preened',
  'prefer',
  'prefers',
  'prepare',
  'prepares',
  'preserve',
  'presided',
  'pressed',
  'presumed',
  'pretend',
  'pretends',
  'prevail',
  'prevent',
  'prevents',
  'preview',
  'preyed',
  'pricked',
  'prickled',
  'prided',
  'pried',
  'primed',
  'printed',
  'prized',
  'probed',
  'proceed',
  'proclaim',
  'procured',
  'prodded',
  'produced',
  'produces',
  'promised',
  'promoted',
  'prompted',
  'propel',
  'proposed',
  'propped',
  'prosper',
  'protect',
  'protects',
  'protrude',
  'proved',
  'proven',
  'proves',
  'provided',
  'provides',
  'provoked',
  'prowl',
  'pry',
  'psych',
  'puckered',
  'puffed',
  'puke',
  'pulled',
  'pulsed',
  'pumped',
  'punched',
  'punished',
  'purchase',
  'purged',
  'purred',
  'pursed',
  'pursued',
  'pursuer',
  'pursuers',
  'pushed',
  'pushes',
  'put',
  'puts',
  'putted',
  'puzzled',
  'puzzles',
  'quaked',
  'qualify',
  'quavered',
  'quench',
  'queried',
  'queryed',
  'queued',
  'quicken',
  'quieted',
  'quirked',
  'quivered',
  'quoted',
  'raced',
  'racked',
  'radiated',
  'raged',
  'railed',
  'rained',
  'raised',
  'raises',
  'raked',
  'rallied',
  'rally',
  'rambled',
  'rammed',
  'ramp',
  'ranged',
  'ranked',
  'ranted',
  'raped',
  'rapped',
  'rasped',
  'rated',
  'rates',
  'rationed',
  'rattled',
  'rattles',
  'ravaged',
  'reached',
  'reaches',
  'reacted',
  'read',
  'readied',
  'reads',
  'realized',
  'realizes',
  'reared',
  'reasoned',
  'reassure',
  'rebuild',
  'rebuilt',
  'rebuke',
  'recalled',
  'receded',
  'recedes',
  'receive',
  'recessed',
  'recited',
  'reckoned',
  'reclaim',
  'reclined',
  'recoiled',
  'recorded',
  'recovered',
  'recruit',
  'recruits',
  'reddened',
  'redeem',
  'redo',
  'redress',
  'reduced',
  'reeked',
  'reeled',
  'refer',
  'referred',
  'refers',
  'reflect',
  'reflects',
  'refocus',
  'reform',
  'refrain',
  'refresh',
  'refused',
  'refuses',
  'regarded',
  'regret',
  'regrets',
  'regroup',
  'regulated',
  'rehearsed',
  'reigned',
  'reined',
  'rejected',
  'rejoiced',
  'rejoined',
  'related',
  'relates',
  'relaxed',
  'relayed',
  'released',
  'releases',
  'relent',
  'relied',
  'relieve',
  'relished',
  'relived',
  'relyed',
  'remained',
  'remarked',
  'remember',
  'reminded',
  'removed',
  'rendered',
  'renewed',
  'renounce',
  'rented',
  'reopened',
  'repaid',
  'repaired',
  'repay',
  'repeat',
  'repeats',
  'repel',
  'repelled',
  'repented',
  'replaced',
  'replayed',
  'replied',
  'replies',
  'replyed',
  'reported',
  'repose',
  'repower',
  'repress',
  'reprieve',
  'repulsed',
  'required',
  'requires',
  'rescued',
  'resemble',
  'resented',
  'reserve',
  'reset',
  'resided',
  'resides',
  'resigned',
  'resisted',
  'resolved',
  'resolves',
  'resorted',
  'resound',
  'restored',
  'restrain',
  'restrict',
  'resulted',
  'resumed',
  'retained',
  'retched',
  'retire',
  'retorted',
  'retract',
  'retrieve',
  'returned',
  'reunited',
  'revealed',
  'reveled',
  'revenge',
  'revered',
  'reversed',
  'reverted',
  'reviewed',
  'revised',
  'revived',
  'revoked',
  'revolted',
  'revolved',
  'revolves',
  'rewarded',
  'reworks',
  'rewrite',
  'ribbed',
  'rid',
  'ridded',
  'riddled',
  'ride',
  'rides',
  'rig',
  'rigged',
  'righted',
  'rinsed',
  'rioted',
  'rip',
  'ripened',
  'rippled',
  'ripples',
  'rips',
  'rise',
  'risen',
  'rises',
  'risked',
  'rivaled',
  'riveted',
  'roamed',
  'roared',
  'roasted',
  'robbed',
  'robber',
  'robed',
  'rocked',
  'roiled',
  'rolled',
  'rooted',
  'rot',
  'rotated',
  'rotted',
  'roughed',
  'rounded',
  'roused',
  'routed',
  'roved',
  'rowed',
  'rub',
  'rubbed',
  'ruined',
  'ruled',
  'rumbled',
  'rumbles',
  'rummaged',
  'rumored',
  'rumpled',
  'run',
  'rushed',
  'rusted',
  'rustled',
  'saddened',
  'saddled',
  'sag',
  'sagged',
  'salted',
  'saluted',
  'sang',
  'sank',
  'sashayed',
  'sated',
  'satisfy',
  'saved',
  'saves',
  'savored',
  'sawed',
  'say',
  'says',
  'scaled',
  'scan',
  'scanned',
  'scans',
  'scared',
  'scares',
  'scarred',
  'scatter',
  'scoffed',
  'scolded',
  'scooped',
  'scooted',
  'scored',
  'scoured',
  'scout',
  'scouts',
  'scowled',
  'scramble',
  'scraped',
  'scrapes',
  'scratch',
  'scrawled',
  'screamed',
  'screened',
  'screwed',
  'scuffed',
  'scuffle',
  'scurried',
  'scuttled',
  'sealed',
  'searched',
  'seared',
  'seasoned',
  'seated',
  'secured',
  'sed',
  'seduced',
  'see',
  'seeked',
  'seekers',
  'seemed',
  'seeped',
  'sees',
  'seethed',
  'seized',
  'selects',
  'selled',
  'sended',
  'sender',
  'sensed',
  'separate',
  'served',
  'serves',
  'set',
  'sets',
  'settled',
  'settles',
  'severed',
  'sewn',
  'shaded',
  'shadowed',
  'shaked',
  'shaken',
  'shakes',
  'shall',
  'shambled',
  'shamed',
  'shaped',
  'shapes',
  'shared',
  'sharpen',
  'shatter',
  'shaved',
  'shaven',
  'sheathed',
  'shed',
  'shedded',
  'sheds',
  'sheer',
  'shielded',
  'shifted',
  'shimmer',
  'shimmied',
  'shined',
  'shines',
  'shipped',
  'shirk',
  'shivered',
  'shocked',
  'shooted',
  'shopped',
  'shorted',
  'shouted',
  'shoved',
  'shoves',
  'showed',
  'showered',
  'shown',
  'shredded',
  'shrieked',
  'shrilled',
  'shrink',
  'shrivel',
  'shrouded',
  'shrug',
  'shrugged',
  'shrugs',
  'shrunk',
  'shrunken',
  'shudder',
  'shudders',
  'shuffled',
  'shun',
  'shushed',
  'shut',
  'shuts',
  'shutted',
  'sidled',
  'sighed',
  'sighted',
  'signaled',
  'signed',
  'signify',
  'silenced',
  'singed',
  'sinked',
  'sip',
  'sipped',
  'sit',
  'sits',
  'sizzled',
  'sketched',
  'skewed',
  'skidded',
  'skill',
  'skills',
  'skim',
  'skimmed',
  'skip',
  'skipped',
  'skulk',
  'slacked',
  'slacken',
  'slammed',
  'slander',
  'slanted',
  'slapped',
  'slashed',
  'slashes',
  'slated',
  'slay',
  'sled',
  'sleek',
  'sleeped',
  'sliced',
  'slices',
  'slicked',
  'slided',
  'slides',
  'slinged',
  'slinked',
  'slip',
  'slipped',
  'slips',
  'slither',
  'slogged',
  'sloped',
  'slopes',
  'sloshed',
  'slouched',
  'slowed',
  'slumber',
  'slumped',
  'slurped',
  'slurred',
  'smacked',
  'smeared',
  'smelled',
  'smiled',
  'smiles',
  'smirked',
  'smite',
  'smoked',
  'smoothed',
  'smudge',
  'smudges',
  'smuggle',
  'snagged',
  'snaked',
  'snap',
  'snapped',
  'snaps',
  'snarled',
  'snatched',
  'snatches',
  'sneaked',
  'sneered',
  'sneezed',
  'sniffed',
  'sniper',
  'snored',
  'snores',
  'snorted',
  'snowed',
  'snub',
  'snuffed',
  'snug',
  'snuggled',
  'soaked',
  'soared',
  'sobbed',
  'sobered',
  'softened',
  'soiled',
  'solace',
  'solved',
  'soothed',
  'sorted',
  'sounded',
  'soured',
  'sown',
  'spaced',
  'spanned',
  'spared',
  'spares',
  'sparked',
  'sparkled',
  'sparkles',
  'sparred',
  'spawned',
  'speak',
  'speaks',
  'speared',
  'specify',
  'speckled',
  'speeded',
  'spelled',
  'spended',
  'spent',
  'spewed',
  'spiced',
  'spied',
  'spiel',
  'spies',
  'spiked',
  'spilled',
  'spilt',
  'spin',
  'spiraled',
  'spitted',
  'splashed',
  'splashes',
  'splayed',
  'split',
  'splits',
  'spoiled',
  'spooked',
  'spooned',
  'sported',
  'spotted',
  'spouted',
  'sprawled',
  'sprayed',
  'spread',
  'spreads',
  'spred',
  'sprinted',
  'sprouted',
  'spruce',
  'spurted',
  'spyed',
  'squall',
  'squared',
  'squashed',
  'squat',
  'squatted',
  'squawked',
  'squeaked',
  'squealed',
  'squeezed',
  'squinted',
  'squirmed',
  'squished',
  'stabbed',
  'staffed',
  'staged',
  'stagger',
  'stained',
  'staked',
  'stalked',
  'stalker',
  'stalled',
  'stammer',
  'stamped',
  'stand',
  'stands',
  'starched',
  'stared',
  'stares',
  'starred',
  'started',
  'startled',
  'starved',
  'stashed',
  'stated',
  'stayed',
  'steadied',
  'stealed',
  'steamed',
  'steeled',
  'steeped',
  'steered',
  'stepped',
  'sticked',
  'stiffen',
  'stifled',
  'stilled',
  'stinged',
  'stink',
  'stinks',
  'stint',
  'stir',
  'stirred',
  'stitched',
  'stitches',
  'stocked',
  'stoke',
  'stomped',
  'stooped',
  'stop',
  'stopped',
  'stops',
  'stored',
  'stores',
  'stormed',
  'stowed',
  'strangle',
  'strapped',
  'strayed',
  'streamed',
  'stretch',
  'strewn',
  'strided',
  'strides',
  'strike',
  'strikes',
  'strip',
  'stripped',
  'strips',
  'strived',
  'stroked',
  'strokes',
  'strolled',
  'struggle',
  'struts',
  'strutted',
  'sts',
  'studded',
  'studyed',
  'stuffed',
  'stumbled',
  'stumped',
  'stung',
  'stunned',
  'stunted',
  'stutter',
  'styled',
  'stylized',
  'subdue',
  'submit',
  'subsided',
  'subvert',
  'succeed',
  'succumb',
  'sucked',
  'sue',
  'suffered',
  'suffused',
  'sugared',
  'suggest',
  'suggests',
  'sulked',
  'summed',
  'summoned',
  'sunburned',
  'sup',
  'supplied',
  'supplies',
  'support',
  'supports',
  'suppose',
  'supposes',
  'suppress',
  'surfaced',
  'surged',
  'surmised',
  'surpass',
  'surround',
  'surveyed',
  'survived',
  'survives',
  'survivor',
  'suspend',
  'sustain',
  'swamped',
  'swap',
  'swapped',
  'swarmed',
  'swathed',
  'swatted',
  'swayed',
  'sweared',
  'sweated',
  'swed',
  'sweep',
  'sweeps',
  'sweeten',
  'swelled',
  'swerved',
  'swim',
  'swimmer',
  'swimmers',
  'swims',
  'swirled',
  'swished',
  'switched',
  'swiveled',
  'swooned',
  'swooped',
  'swung',
  'tacked',
  'tackled',
  'tagged',
  'tainted',
  'taked',
  'takes',
  'talked',
  'talkers',
  'tamed',
  'tan',
  'tangled',
  'tangles',
  'tanned',
  'taped',
  'tapered',
  'tapped',
  'targeted',
  'tarry',
  'tasted',
  'tastes',
  'tatters',
  'tattooed',
  'taunted',
  'taxed',
  'taxes',
  'teach',
  'teased',
  'tell',
  'tells',
  'temper',
  'tempted',
  'tended',
  'tensed',
  'terms',
  'terrify',
  'testify',
  'tethered',
  'thanked',
  'thatched',
  'thaw',
  'thicken',
  'think',
  'thinkers',
  'thinks',
  'thinned',
  'thrashed',
  'threaded',
  'threaten',
  'thrilled',
  'thrived',
  'throats',
  'throb',
  'throbbed',
  'throttle',
  'throwed',
  'thrown',
  'thrust',
  'thrusts',
  'thudded',
  'thumbed',
  'thumped',
  'thwarted',
  'tickled',
  'tidyed',
  'tied',
  'tighten',
  'tiled',
  'tiles',
  'tilted',
  'tinge',
  'tingled',
  'tingles',
  'tinkled',
  'tinted',
  'tip',
  'tipped',
  'tips',
  'tiptoed',
  'tired',
  'toast',
  'toiled',
  'tolerate',
  'tolled',
  'tooled',
  'toppled',
  'tortured',
  'tossed',
  'toted',
  'tottered',
  'touch',
  'touches',
  'tousled',
  'towed',
  'toyed',
  'traced',
  'tracker',
  'traded',
  'trailed',
  'trained',
  'tramped',
  'trampled',
  'transfer',
  'transmit',
  'trapped',
  'trashed',
  'travel',
  'travels',
  'treaded',
  'treated',
  'trek',
  'trembled',
  'trembles',
  'trend',
  'tricked',
  'trickled',
  'tries',
  'trill',
  'trim',
  'trimmed',
  'trip',
  'triple',
  'tripped',
  'trips',
  'trotted',
  'troubled',
  'troubles',
  'trucked',
  'trudged',
  'trundled',
  'trussed',
  'trusted',
  'try',
  'tucked',
  'tug',
  'tugged',
  'tugs',
  'tumbled',
  'tumbles',
  'tuned',
  'turned',
  'tweaked',
  'twined',
  'twinge',
  'twinkled',
  'twirled',
  'twist',
  'twists',
  'twitched',
  'twitches',
  'typed',
  'unbent',
  'undercut',
  'undergo',
  'undid',
  'undo',
  'undress',
  'unfold',
  'unfolds',
  'unfurled',
  'unhooked',
  'uniforms',
  'united',
  'unleash',
  'unloaded',
  'unlocked',
  'unnerved',
  'unpacked',
  'unravel',
  'unrolled',
  'unsteady',
  'untied',
  'untyed',
  'unwind',
  'unwound',
  'unzipped',
  'updated',
  'updates',
  'upended',
  'uphold',
  'upraised',
  'upset',
  'upsets',
  'upturned',
  'urged',
  'urges',
  'used',
  'ushered',
  'usurped',
  'uttered',
  'vacated',
  'vanished',
  'vanishes',
  'varyed',
  'veered',
  'vented',
  'ventured',
  'verify',
  'vest',
  'vibrated',
  'vied',
  'viewed',
  'violated',
  'visited',
  'voiced',
  'vomited',
  'voted',
  'vouch',
  'vowed',
  'wadded',
  'waddled',
  'waded',
  'wafted',
  'wag',
  'wagered',
  'wagged',
  'waggled',
  'wailed',
  'waited',
  'wake',
  'wakened',
  'wakes',
  'walked',
  'walled',
  'wandered',
  'wanderer',
  'waned',
  'wanted',
  'warbled',
  'wares',
  'warmed',
  'warned',
  'warped',
  'warred',
  'washed',
  'washes',
  'watched',
  'watches',
  'watered',
  'waved',
  'wavered',
  'waxed',
  'weakened',
  'wear',
  'weaved',
  'wedded',
  'weeped',
  'weighed',
  'welcomed',
  'welled',
  'welshed',
  'wetted',
  'whacked',
  'wheezed',
  'whimpered',
  'whined',
  'whinnied',
  'whipped',
  'whirled',
  'whirred',
  'whisked',
  'whispered',
  'whistled',
  'whitened',
  'whooped',
  'widened',
  'widowed',
  'wielded',
  'wiggled',
  'willed',
  'wilted',
  'winced',
  'winded',
  'winked',
  'wiped',
  'wished',
  'withdraw',
  'withdrew',
  'withered',
  'withheld',
  'wobbled',
  'won',
  'wondered',
  'wooed',
  'worded',
  'wore',
  'worked',
  'wormed',
  'worried',
  'worries',
  'worryed',
  'worsened',
  'would',
  'wracked',
  'wrang',
  'wrapped',
  'wreathed',
  'wrenched',
  'wrestled',
  'wriggled',
  'wringed',
  'wrinkled',
  'writhed',
  'written',
  'xed',
  'yanked',
  'yawned',
  'yearned',
  'yelled',
  'yellowed',
  'yelped',
  'yielded',
  'zipped',
  'zoomed'
]
adjs = [
  'cruel',
  'infamous',
  'humanoid',
  'learned',
  'mortal',
  'trans',
  'foregone',
  'eldest',
  'modest',
  'dropped',
  'richer',
  'keenly',
  'mighty',
  'diagonal',
  'wanton',
  'strained',
  'resolute',
  'married',
  'bedded',
  'rigid',
  'chunky',
  'obsolete',
  'gray',
  'tempting',
  'cozy',
  'sluggish',
  'privy',
  'baleful',
  'previous',
  'numb',
  'slack',
  'regional',
  'bravely',
  'sore',
  'bay',
  'steadily',
  'studied',
  'smoky',
  'artistic',
  'silly',
  'super',
  'wild',
  'wildest',
  'cracked',
  'gruesome',
  'longest',
  'wealthy',
  'silky',
  'outward',
  'fluid',
  'fixedly',
  'lucid',
  'restful',
  'mutually',
  'obliging',
  'mentally',
  'luscious',
  'astern',
  'mild',
  'cordial',
  'feline',
  'upright',
  'fair',
  'tragic',
  'worked',
  'sided',
  'deprived',
  'timidly',
  'lonely',
  'cool',
  'hooded',
  'definite',
  'hopeful',
  'naked',
  'indirect',
  'verbal',
  'patent',
  'loaded',
  'sharpest',
  'peaked',
  'sedate',
  'solemnly',
  'gone',
  'western',
  'ravenous',
  'reputed',
  'implicit',
  'divine',
  'intrepid',
  'vastly',
  'witted',
  'hollowly',
  'ashamed',
  'local',
  'certain',
  'morose',
  'striking',
  'factly',
  'haired',
  'gory',
  'cruelly',
  'safest',
  'marked',
  'jagged',
  'express',
  'wildness',
  'reverse',
  'thumping',
  'sobering',
  'colored',
  'downy',
  'abiding',
  'retro',
  'famous',
  'eligible',
  'ajar',
  'quieter',
  'holy',
  'mundane',
  'fresh',
  'figured',
  'bravest',
  'hardest',
  'unjust',
  'dedicate',
  'selected',
  'serious',
  'gifted',
  'liquid',
  'precious',
  'better',
  'windy',
  'stirring',
  'explicit',
  'inland',
  'unwashed',
  'garish',
  'poor',
  'final',
  'waking',
  'marbled',
  'viable',
  'thickly',
  'utterly',
  'bleary',
  'clinical',
  'lucky',
  'properly',
  'immortal',
  'pristine',
  'unlisted',
  'resonant',
  'empire',
  'tightly',
  'psychic',
  'latter',
  'known',
  'gloomy',
  'busily',
  'atop',
  'unstable',
  'shortest',
  'stolidly',
  'ceramic',
  'lowest',
  'lateral',
  'shakily',
  'personal',
  'reformed',
  'absently',
  'hammered',
  'uncommon',
  'dizzy',
  'bloodred',
  'squalid',
  'happy',
  'mossy',
  'green',
  'inbound',
  'girlish',
  'bulky',
  'crooked',
  'abreast',
  'sweaty',
  'yellow',
  'childish',
  'stocky',
  'hellish',
  'digital',
  'bounded',
  'fanatics',
  'helpful',
  'watery',
  'vast',
  'radical',
  'lofty',
  'airborne',
  'helpless',
  'stated',
  'real',
  'obvious',
  'unkempt',
  'plus',
  'burly',
  'platonic',
  'pious',
  'askew',
  'squint',
  'warded',
  'white',
  'missile',
  'organic',
  'grudging',
  'sage',
  'clubbed',
  'graphic',
  'logical',
  'ignorant',
  'blasted',
  'polite',
  'passive',
  'enduring',
  'detached',
  'hallowed',
  'young',
  'thankful',
  'spiral',
  'bats',
  'spiked',
  'playful',
  'physical',
  'mellow',
  'reborn',
  'brisk',
  'infrared',
  'perfect',
  'driven',
  'sickly',
  'unworthy',
  'icy',
  'numbing',
  'sardonic',
  'sparsely',
  'blocked',
  'unarmed',
  'shady',
  'old',
  'tearful',
  'owing',
  'wavy',
  'concrete',
  'halting',
  'all',
  'sloshed',
  'thy',
  'topmost',
  'abruptly',
  'uneasy',
  'regular',
  'coolly',
  'tempered',
  'outbound',
  'ocular',
  'exotic',
  'bizarre',
  'motley',
  'eating',
  'hateful',
  'humbly',
  'gothic',
  'erotic',
  'shrilly',
  'nasty',
  'wet',
  'wrongly',
  'blissful',
  'twisted',
  'quickest',
  'speaking',
  'anxious',
  'red',
  'notable',
  'european',
  'gilt',
  'dully',
  'total',
  'nobler',
  'skittish',
  'nimbly',
  'habitual',
  'mine',
  'eventual',
  'nicely',
  'cobbled',
  'brittle',
  'potent',
  'huge',
  'spurred',
  'global',
  'rhythmic',
  'rugged',
  'surgical',
  'ablaze',
  'mousy',
  'timid',
  'complete',
  'sombre',
  'content',
  'third',
  'flatly',
  'profound',
  'unsealed',
  'dense',
  'daunting',
  'hours',
  'tiniest',
  'studious',
  'black',
  'poignant',
  'negative',
  'historic',
  'behind',
  'wood',
  'luminous',
  'bad',
  'colorful',
  'muscular',
  'vagabond',
  'diffuse',
  'wasting',
  'romance',
  'frozen',
  'dampness',
  'pitying',
  'sculpted',
  'drowsy',
  'unquiet',
  'snide',
  'probable',
  'multiple',
  'deeper',
  'hot',
  'horrible',
  'necked',
  'sagely',
  'hairy',
  'eerily',
  'smoother',
  'scotch',
  'nonstop',
  'darkness',
  'tailored',
  'muscled',
  'sad',
  'grateful',
  'foreign',
  'unfair',
  'cute',
  'closely',
  'faint',
  'bodied',
  'sporadic',
  'scrawny',
  'bleeding',
  'sexual',
  'loving',
  'expanded',
  'parched',
  'sterner',
  'infinite',
  'undone',
  'fetal',
  'gingerly',
  'giddy',
  'rigidly',
  'higher',
  'divers',
  'musky',
  'toned',
  'humble',
  'mental',
  'symbolic',
  'feigned',
  'rakish',
  'lopsided',
  'late',
  'overdue',
  'meek',
  'godly',
  'valid',
  'fried',
  'informal',
  'bombed',
  'furthest',
  'dynamic',
  'severely',
  'open',
  'paleness',
  'spidery',
  'usual',
  'ecstatic',
  'extended',
  'scathing',
  'shyly',
  'idle',
  'mobile',
  'artfully',
  'scarce',
  'becoming',
  'dimly',
  'colder',
  'flinty',
  'ethereal',
  'hasty',
  'easiest',
  'immature',
  'sensibly',
  'criminal',
  'oddest',
  'capable',
  'right',
  'coherent',
  'charming',
  'unclean',
  'natural',
  'biggest',
  'subtle',
  'barbed',
  'defunct',
  'blatant',
  'muted',
  'chilly',
  'null',
  'poised',
  'opposite',
  'slope',
  'sick',
  'closest',
  'stringy',
  'greedily',
  'oncoming',
  'prickly',
  'galactic',
  'glum',
  'furtive',
  'barred',
  'memorial',
  'hungry',
  'graceful',
  'morbid',
  'affected',
  'dreamy',
  'micro',
  'sales',
  'breathed',
  'rational',
  'untold',
  'earthy',
  'weaker',
  'entire',
  'smugly',
  'coldly',
  'unseemly',
  'weak',
  'blazing',
  'serial',
  'faintest',
  'plastic',
  'simple',
  'sour',
  'regal',
  'clumsily',
  'rudely',
  'imperial',
  'weary',
  'featured',
  'rampant',
  'hapless',
  'prow',
  'tart',
  'emerging',
  'lengthy',
  'colonial',
  'deadly',
  'cooking',
  'portly',
  'maudlin',
  'overt',
  'damaging',
  'husky',
  'foremost',
  'scaly',
  'vacant',
  'vastness',
  'assured',
  'dimness',
  'pitted',
  'commonly',
  'rotten',
  'wary',
  'majestic',
  'humid',
  'clean',
  'pumped',
  'leading',
  'virtuous',
  'ruthless',
  'cursory',
  'sexually',
  'benign',
  'somber',
  'defiant',
  'blue',
  'interior',
  'heedless',
  'broadly',
  'silent',
  'harsh',
  'angrily',
  'meekly',
  'jealous',
  'infernal',
  'tangled',
  'brightly',
  'many',
  'oriental',
  'angrier',
  'fat',
  'vague',
  'scheming',
  'sighted',
  'swimming',
  'tested',
  'bare',
  'inward',
  'wanting',
  'odd',
  'movable',
  'amiable',
  'elderly',
  'sodden',
  'wearing',
  'solitary',
  'petty',
  'crusty',
  'beloved',
  'waxy',
  'placidly',
  'breezy',
  'every',
  'afoot',
  'virtual',
  'purest',
  'supreme',
  'isolated',
  'sweetly',
  'static',
  'grandly',
  'marshy',
  'national',
  'pleasing',
  'taller',
  'tutorial',
  'needless',
  'terrible',
  'spotted',
  'hoarsely',
  'dusk',
  'serene',
  'dark',
  'formally',
  'prodigal',
  'wisest',
  'coldest',
  'staid',
  'grimly',
  'touchy',
  'stuffy',
  'joyful',
  'funereal',
  'brawny',
  'pressing',
  'quicker',
  'exempt',
  'airy',
  'knotty',
  'pensive',
  'rank',
  'quick',
  'fast',
  'slow',
  'yawning',
  'awry',
  'windowed',
  'patient',
  'cynical',
  'strictly',
  'cheery',
  'inner',
  'pent',
  'ripped',
  'measured',
  'imminent',
  'sincere',
  'genial',
  'milder',
  'faintly',
  'crunchy',
  'futile',
  'visibly',
  'molten',
  'horrid',
  'barest',
  'damned',
  'dull',
  'willful',
  'callous',
  'inhuman',
  'angular',
  'rousing',
  'suicidal',
  'eerie',
  'bluff',
  'bloody',
  'footed',
  'proper',
  'stubby',
  'slight',
  'narrower',
  'ago',
  'idyllic',
  'nervous',
  'alone',
  'ware',
  'little',
  'safely',
  'awed',
  'hostile',
  'awkward',
  'primly',
  'faster',
  'primal',
  'secluded',
  'lively',
  'swept',
  'festive',
  'crude',
  'stressed',
  'fearless',
  'dismal',
  'jumpy',
  'toxic',
  'unlucky',
  'rickety',
  'meanest',
  'dead',
  'unused',
  'ironic',
  'bald',
  'towering',
  'sheepish',
  'picked',
  'sec',
  'speedy',
  'outdoor',
  'formed',
  'unusual',
  'absolute',
  'cold',
  'normal',
  'dirty',
  'punctual',
  'hazy',
  'astray',
  'stiff',
  'lesser',
  'woolen',
  'ringing',
  'opaque',
  'aching',
  'frail',
  'dreary',
  'piquant',
  'extra',
  'own',
  'touched',
  'petite',
  'canned',
  'embedded',
  'valued',
  'fiery',
  'grubby',
  'daring',
  'literary',
  'liable',
  'possible',
  'brash',
  'hotter',
  'purple',
  'frank',
  'costly',
  'english',
  'sullenly',
  'dear',
  'advised',
  'pelting',
  'naval',
  'breathy',
  'strait',
  'retiring',
  'bold',
  'ardent',
  'linen',
  'tinny',
  'austere',
  'proud',
  'online',
  'celsius',
  'seething',
  'powdery',
  'varied',
  'gorgeous',
  'stupidly',
  'needful',
  'foolish',
  'tangy',
  'past',
  'heaviest',
  'sane',
  'active',
  'ethnic',
  'timidity',
  'thick',
  'urgently',
  'evident',
  'surer',
  'faithful',
  'engaged',
  'scented',
  'achieved',
  'amiably',
  'smart',
  'improper',
  'severity',
  'lawful',
  'lumpy',
  'dumbly',
  'harder',
  'elusive',
  'biting',
  'waved',
  'deceased',
  'slim',
  'fabulous',
  'our',
  'pitiable',
  'distinct',
  'its',
  'dusty',
  'rashly',
  'med',
  'deepest',
  'sleepily',
  'enormous',
  'drastic',
  'lame',
  'obedient',
  'minded',
  'tactical',
  'glazed',
  'decent',
  'murky',
  'lazy',
  'radio',
  'decrepit',
  'large',
  'tranquil',
  'gravely',
  'superior',
  'removed',
  'accepted',
  'softness',
  'queasy',
  'situated',
  'medical',
  'nuclear',
  'violent',
  'risky',
  'built',
  'sonorous',
  'grand',
  'chemical',
  'portable',
  'noblest',
  'waxen',
  'homeless',
  'reverend',
  'splendid',
  'nosed',
  'branded',
  'naive',
  'solar',
  'wayward',
  'smashing',
  'rested',
  'abroad',
  'reliable',
  'harsher',
  'neatly',
  'prudent',
  'great',
  'blooded',
  'long',
  'sullen',
  'scanty',
  'glaring',
  'initial',
  'snugly',
  'merest',
  'central',
  'softer',
  'crisply',
  'cleverly',
  'vexed',
  'louder',
  'jaunty',
  'desirous',
  'spotless',
  'living',
  'accursed',
  'inclined',
  'smartly',
  'careful',
  'several',
  'communal',
  'rapid',
  'endless',
  'growling',
  'sticky',
  'lifelike',
  'heathen',
  'funniest',
  'aware',
  'unreal',
  'absurdly',
  'impotent',
  'lidded',
  'narrow',
  'foggy',
  'dank',
  'scant',
  'fitted',
  'niggling',
  'fertile',
  'comic',
  'bushy',
  'mouthed',
  'dusky',
  'sorry',
  'hideous',
  'logged',
  'unhappy',
  'opposed',
  'whose',
  'supple',
  'grisly',
  'assorted',
  'stylish',
  'romantic',
  'wee',
  'arrogant',
  'openly',
  'patchy',
  'surly',
  'gigantic',
  'moderate',
  'coppery',
  'bluntly',
  'hectic',
  'teenage',
  'verdant',
  'fetching',
  'beady',
  'sensible',
  'vicious',
  'second',
  'jovial',
  'scalding',
  'bound',
  'ghastly',
  'tougher',
  'vainly',
  'magnetic',
  'wishing',
  'eternal',
  'hearty',
  'briskly',
  'merciful',
  'lilting',
  'mature',
  'furry',
  'sure',
  'strongly',
  'grown',
  'ringed',
  'generous',
  'morally',
  'pretty',
  'nauseous',
  'harmful',
  'subtly',
  'unseen',
  'skeletal',
  'telling',
  'downtown',
  'facial',
  'unfolded',
  'latin',
  'whole',
  'sturdy',
  'new',
  'lithe',
  'steep',
  'abject',
  'abnormal',
  'skilled',
  'shaky',
  'composed',
  'vital',
  'justly',
  'weakest',
  'mum',
  'hopeless',
  'innocent',
  'vulgar',
  'nearness',
  'nubile',
  'brutal',
  'sadness',
  'dogged',
  'leaden',
  'messy',
  'two',
  'stubborn',
  'plainly',
  'nightly',
  'skinned',
  'glumly',
  'wide',
  'forlorn',
  'each',
  'nipping',
  'illegal',
  'grueling',
  'dumb',
  'sizable',
  'your',
  'halt',
  'forked',
  'variable',
  'void',
  'sacred',
  'absurd',
  'remotely',
  'fervent',
  'tenderly',
  'actual',
  'horribly',
  'minor',
  'sleepy',
  'toasty',
  'obscure',
  'coolest',
  'juicy',
  'japan',
  'greedy',
  'edible',
  'mixed',
  'spacious',
  'noisily',
  'electric',
  'pompous',
  'mincing',
  'inlaid',
  'tropical',
  'special',
  'guiltily',
  'impacted',
  'happiest',
  'timed',
  'prettier',
  'loudly',
  'full',
  'tough',
  'sweated',
  'distract',
  'ruefully',
  'finished',
  'ripping',
  'pied',
  'booted',
  'grimy',
  'epic',
  'languid',
  'metallic',
  'cloudy',
  'stricken',
  'nodding',
  'keener',
  'choking',
  'pleasant',
  'folding',
  'antique',
  'awful',
  'panic',
  'taut',
  'hidden',
  'sober',
  'darker',
  'testing',
  'extinct',
  'forward',
  'sourly',
  'double',
  'sly',
  'needy',
  'awless',
  'tender',
  'glossy',
  'tolerant',
  'edgy',
  'curt',
  'nuts',
  'blown',
  'pallid',
  'valuable',
  'one',
  'haughty',
  'fetid',
  'awash',
  'outer',
  'smallish',
  'handy',
  'brief',
  'eager',
  'rougher',
  'firmness',
  'deftly',
  'her',
  'winged',
  'wretched',
  'unasked',
  'external',
  'rubbery',
  'any',
  'joyous',
  'outlying',
  'delicate',
  'harried',
  'rabid',
  'more',
  'material',
  'droll',
  'ripe',
  'adhesive',
  'curious',
  'sweet',
  'amazing',
  'gruff',
  'weeping',
  'armored',
  'superb',
  'envious',
  'wooded',
  'martial',
  'denser',
  'drily',
  'arcane',
  'roomy',
  'fuzzy',
  'jawed',
  'detailed',
  'most',
  'moist',
  'worst',
  'sounding',
  'zealous',
  'simpler',
  'tops',
  'bonded',
  'briefest',
  'boring',
  'stolid',
  'steeper',
  'timeless',
  'slender',
  'filthy',
  'piercing',
  'stalwart',
  'nimble',
  'laptop',
  'ratty',
  'thine',
  'deathly',
  'rocky',
  'unruly',
  'craggy',
  'foul',
  'private',
  'reedy',
  'usable',
  'raging',
  'perilous',
  'wheeled',
  'forcible',
  'crabbed',
  'quietly',
  'relevant',
  'still',
  'smoothly',
  'hispanic',
  'lethal',
  'mosaic',
  'maternal',
  'ugly',
  'silently',
  'much',
  'marine',
  'ornate',
  'nosy',
  'firm',
  'airily',
  'watchful',
  'fatal',
  'tonic',
  'lifeless',
  'left',
  'grim',
  'insane',
  'obscene',
  'warily',
  'plumed',
  'gracious',
  'future',
  'brusque',
  'ungainly',
  'visual',
  'odious',
  'only',
  'very',
  'grasping',
  'clueless',
  'upcoming',
  'fruitful',
  'ill',
  'vertical',
  'nebulous',
  'cocky',
  'demurely',
  'usually',
  'soggy',
  'overripe',
  'noisy',
  'calmly',
  'glassy',
  'tacky',
  'marital',
  'acrid',
  'nice',
  'sloppy',
  'hooked',
  'arctic',
  'blind',
  'clever',
  'tight',
  'uncanny',
  'lax',
  'signed',
  'dry',
  'fleeting',
  'confused',
  'dilated',
  'boldly',
  'popular',
  'whispery',
  'barefoot',
  'warm',
  'blond',
  'captive',
  'ridden',
  'smashed',
  'newfound',
  'genially',
  'armed',
  'moral',
  'strong',
  'shocking',
  'feudal',
  'irate',
  'slimy',
  'bitterly',
  'doubtful',
  'dreadful',
  'advanced',
  'good',
  'blurry',
  'livid',
  'ambient',
  'numbness',
  'dirtier',
  'beaten',
  'ironical',
  'sheen',
  'faulty',
  'deeply',
  'blunt',
  'retired',
  'throated',
  'whiter',
  'bowed',
  'axis',
  'modestly',
  'cloying',
  'scrubbed',
  'freshly',
  'cheaply',
  'shrewd',
  'resident',
  'reserved',
  'numerous',
  'flat',
  'pitiless',
  'misty',
  'fastest',
  'sensual',
  'busier',
  'boiling',
  'rarest',
  'tired',
  'paltry',
  'icily',
  'wiser',
  'grizzled',
  'teenager',
  'tedious',
  'vaunted',
  'unbidden',
  'dearest',
  'akin',
  'fainter',
  'civil',
  'lunatic',
  'least',
  'brimmed',
  'less',
  'stingy',
  'forcibly',
  'losing',
  'casually',
  'deep',
  'due',
  'bereft',
  'narrowly',
  'rife',
  'amusing',
  'feeble',
  'decided',
  'striped',
  'lovingly',
  'spectral',
  'tall',
  'fixed',
  'coldness',
  'placid',
  'bouncing',
  'received',
  'hungrily',
  'lukewarm',
  'extreme',
  'savagely',
  'tighter',
  'softest',
  'fanciful',
  'aquiline',
  'raw',
  'crashing',
  'roaring',
  'next',
  'daily',
  'literal',
  'similar',
  'unheard',
  'innate',
  'bright',
  'vigilant',
  'toward',
  'oral',
  'eminent',
  'kindest',
  'comical',
  'asleep',
  'precise',
  'rainy',
  'sultry',
  'cheaper',
  'intended',
  'tricky',
  'same',
  'vividly',
  'slower',
  'free',
  'furred',
  'merely',
  'rich',
  'gloomily',
  'assuming',
  'coy',
  'errant',
  'scary',
  'leathery',
  'robust',
  'big',
  'burning',
  'flying',
  'grimness',
  'prying',
  'paranoid',
  'sensuous',
  'intently',
  'pitiful',
  'larger',
  'loose',
  'securely',
  'hanging',
  'departed',
  'dim',
  'undersea',
  'middle',
  'nude',
  'tipsy',
  'unkind',
  'volcanic',
  'viral',
  'some',
  'applied',
  'decently',
  'ragged',
  'raspy',
  'scorched',
  'born',
  'looped',
  'lipped',
  'crested',
  'guilty',
  'wickedly',
  'pissed',
  'lewd',
  'handed',
  'fragile',
  'barren',
  'lush',
  'dutiful',
  'vaguely',
  'mute',
  'untrue',
  'raised',
  'constant',
  'royal',
  'ticked',
  'halfway',
  'ahead',
  'given',
  'aghast',
  'aged',
  'cultural',
  'shining',
  'limply',
  'ruddy',
  'busy',
  'steeply',
  'deserved',
  'cautious',
  'forced',
  'sordid',
  'missing',
  'heady',
  'lenient',
  'suspect',
  'cheerful',
  'radiant',
  'sternly',
  'rigorous',
  'likely',
  'asian',
  'howling',
  'wearily',
  'parallel',
  'shorter',
  'immobile',
  'flaming',
  'devout',
  'wedged',
  'keen',
  'peculiar',
  'mournful',
  'elastic',
  'macabre',
  'valiant',
  'savage',
  'willing',
  'gauzy',
  'female',
  'expert',
  'positive',
  'cryptic',
  'heroic',
  'steady',
  'catching',
  'sized',
  'merry',
  'acute',
  'perverse',
  'ordered',
  'rapidly',
  'secret',
  'accurate',
  'hardy',
  'noisome',
  'braided',
  'sensory',
  'blooming',
  'veined',
  'paler',
  'liberal',
  'vivid',
  'oriented',
  'dramatic',
  'wisely',
  'docile',
  'durable',
  'renowned',
  'urgent',
  'ritual',
  'haggard',
  'cosmetic',
  'intense',
  'feathery',
  'deferred',
  'brave',
  'centered',
  'creative',
  'grayish',
  'adequate',
  'sibilant',
  'healthy',
  'pregnant',
  'engaging',
  'lunged',
  'restless',
  'awfully',
  'older',
  'gay',
  'public',
  'passable',
  'devoted',
  'deadpan',
  'unwary',
  'stale',
  'abundant',
  'unending',
  'vile',
  'eastern',
  'soothing',
  'loyally',
  'manual',
  'chiseled',
  'fond',
  'densest',
  'apt',
  'horny',
  'racial',
  'comely',
  'famished',
  'demure',
  'ranking',
  'paved',
  'lowering',
  'concise',
  'steamed',
  'deft',
  'soreness',
  'funny',
  'tiredly',
  'specific',
  'inched',
  'tame',
  'internal',
  'able',
  'homey',
  'stout',
  'single',
  'posh',
  'farthest',
  'mildly',
  'vibrant',
  'critical',
  'darkly',
  'dashing',
  'evenly',
  'numbly',
  'compact',
  'fragrant',
  'luckier',
  'upscale',
  'involved',
  'other',
  'united',
  'spindly',
  'cultured',
  'northern',
  'veiled',
  'worthy',
  'humorous',
  'lousy',
  'sunless',
  'normally',
  'audio',
  'dire',
  'gaudy',
  'adorable',
  'sweetest',
  'intact',
  'loud',
  'confined',
  'friendly',
  'quit',
  'upper',
  'lasting',
  'inspired',
  'wooden',
  'verbally',
  'leafy',
  'fabled',
  'visiting',
  'sporting',
  'mutely',
  'richest',
  'another',
  'deformed',
  'tiresome',
  'viscous',
  'onboard',
  'lost',
  'okay',
  'glad',
  'ain',
  'lastly',
  'oiled',
  'limited',
  'unable',
  'akimbo',
  'sweeter',
  'powerful',
  'alive',
  'bloated',
  'easier',
  'honest',
  'tudor',
  'frosted',
  'wont',
  'clearest',
  'tearing',
  'actively',
  'puny',
  'soft',
  'potted',
  'sucking',
  'dated',
  'cosmic',
  'solemn',
  'curve',
  'gritty',
  'painful',
  'bleak',
  'smug',
  'genetic',
  'slashing',
  'teary',
  'elect',
  'grossly',
  'ready',
  'worse',
  'woefully',
  'lone',
  'crazy',
  'sparse',
  'broken',
  'partial',
  'mad',
  'pliant',
  'smartest',
  'parted',
  'acutely',
  'feverish',
  'select',
  'domestic',
  'sandy',
  'frantic',
  'stony',
  'desolate',
  'recent',
  'alleged',
  'newer',
  'oily',
  'native',
  'tribal',
  'shaggy',
  'tiny',
  'jolly',
  'legal',
  'sharp',
  'indecent',
  'gnarled',
  'inviting',
  'slippery',
  'chaste',
  'stacked',
  'goodly',
  'terse',
  'tallest',
  'frosty',
  'cellular',
  'tattered',
  'scenes',
  'blessed',
  'comatose',
  'tangent',
  'sharply',
  'sideways',
  'smaller',
  'towards',
  'unbroken',
  'linked',
  'optical',
  'wasted',
  'stranded',
  'strange',
  'insolent',
  'troubled',
  'gaping',
  'divided',
  'shy',
  'erratic',
  'gravelly',
  'brighter',
  'directed',
  'singular',
  'suitable',
  'wider',
  'thirsty',
  'rapt',
  'abortive',
  'voiced',
  'handmade',
  'abed',
  'captives',
  'silken',
  'oblique',
  'gladness',
  'sterile',
  'greatest',
  'moldy',
  'warmest',
  'straight',
  'slightly',
  'empty',
  'equal',
  'wronged',
  'bolder',
  'naughty',
  'glancing',
  'audibly',
  'oblong',
  'maniacal',
  'rude',
  'oblongs',
  'broad',
  'ideal',
  'unevenly',
  'masked',
  'mannered',
  'deciding',
  'humane',
  'rough',
  'muddy',
  'longer',
  'artful',
  'traveled',
  'mystical',
  'unique',
  'creeping',
  'military',
  'optimal',
  'cunning',
  'used',
  'smooth',
  'candidly',
  'belated',
  'subdued',
  'galling',
  'swinging',
  'annual',
  'spiky',
  'true',
  'loosely',
  'hale',
  'blonde',
  'ongoing',
  'various',
  'scared',
  'chief',
  'lanky',
  'carefree',
  'cant',
  'derived',
  'openness',
  'willed',
  'tracked',
  'swarthy',
  'bony',
  'sneaking',
  'astral',
  'remote',
  'devoid',
  'stewed',
  'worldly',
  'wordless',
  'visually',
  'uneven',
  'genteel',
  'funeral',
  'hid',
  'stark',
  'unwise',
  'quickly',
  'stiffer',
  'melting',
  'spirited',
  'broader',
  'juvenile',
  'attached',
  'bleakly',
  'surreal',
  'mid',
  'terminal',
  'noble',
  'festival',
  'moving',
  'crucial',
  'raggedly',
  'novel',
  'relieved',
  'hurried',
  'athletic',
  'bracing',
  'sturdily',
  'masters',
  'paternal',
  'solid',
  'secure',
  'wryly',
  'useless',
  'crying',
  'nicer',
  'turkish',
  'cleverer',
  'calmer',
  'upriver',
  'handheld',
  'wintry',
  'casual',
  'marginal',
  'fearsome',
  'frenzied',
  'puzzling',
  'sinful',
  'hard',
  'grassy',
  'balding',
  'discrete',
  'ominous',
  'abrupt',
  'summary',
  'moonlit',
  'crisp',
  'sundry',
  'salty',
  'shrewdly',
  'inert',
  'faraway',
  'floating',
  'brute',
  'knotted',
  'idiotic',
  'adjacent',
  'steepest',
  'diurnal',
  'exploded',
  'gross',
  'merrily',
  'curly',
  'hulking',
  'calmness',
  'kindly',
  'scots',
  'dizzily',
  'tasteful',
  'caustic',
  'lazily',
  'brushed',
  'sanguine',
  'sunken',
  'charged',
  'imposing',
  'derisive',
  'stern',
  'their',
  'immense',
  'evasive',
  'best',
  'crudely',
  'unequal',
  'charmed',
  'unknown',
  'musical',
  'drunken',
  'damning',
  'adjusted',
  'indoor',
  'westward',
  'chested',
  'forensic',
  'disused',
  'which',
  'stagnant',
  'rosy',
  'manifold',
  'falsely',
  'boldest',
  'discreet',
  'petulant',
  'eagerly',
  'wired',
  'sound',
  'sadder',
  'related',
  'weakly',
  'small',
  'soberly',
  'aboard',
  'sinister',
  'clumsy',
  'spinal',
  'soprano',
  'diverse',
  'gaunt',
  'pungent',
  'rangy',
  'visible',
  'golden',
  'mindless',
  'grainy',
  'exposed',
  'redder',
  'satiny',
  'bigger',
  'rebel',
  'former',
  'crazily',
  'jerky',
  'bland',
  'repeated',
  'doggedly',
  'ick',
  'cleanest',
  'secondly',
  'skinny',
  'curtly',
  'palpable',
  'furious',
  'legally',
  'unlikely',
  'shabby',
  'standing',
  'vested',
  'his',
  'classic',
  'chatty',
  'pure',
  'witty',
  'plugged',
  'limiting',
  'easy',
  'chilling',
  'poetic',
  'stronger',
  'royally',
  'rustic',
  'baggy',
  'tangible',
  'truthful',
  'clear',
  'vaulted',
  'audible',
  'pierced',
  'smarter',
  'dingy',
  'demonic',
  'fierce',
  'steamy',
  'educated',
  'feminine',
  'elegant',
  'plains',
  'packed',
  'heavenly',
  'futilely',
  'soundly',
  'gentle',
  'formal',
  'rimmed',
  'resting',
  'frigid',
  'scratchy',
  'finally',
  'coolness',
  'safer',
  'wiry',
  'exciting',
  'spoken',
  'piled',
  'made',
  'polish',
  'stealthy',
  'proudly',
  'vain',
  'rotund',
  'spatial',
  'milky',
  'stumpy',
  'cursed',
  'killed',
  'musty',
  'brazen',
  'such',
  'pinkish',
  'slowness',
  'kinder',
  'mobility',
  'manually',
  'evil',
  'current',
  'swift',
  'ancient',
  'vigorous',
  'dryly',
  'minimal',
  'nastier',
  'heavy',
  'headed',
  'secretly',
  'landed',
  'grounded',
  'bluish',
  'palest',
  'relaxed',
  'rotate',
  'measly',
  'dormant',
  'staccato',
  'economic',
  'elevated',
  'ghostly',
  'round',
  'erect',
  'dubious',
  'solidly',
  'orderly',
  'legged',
  'afraid',
  'untidy',
  'hesitant',
  'common',
  'either',
  'ashen',
  'pained',
  'clammy',
  'sexy',
  'human',
  'handsome',
  'driving',
  'heavier',
  'snowy',
  'tried',
  'supposed',
  'bruising',
  'wistful',
  'smelly',
  'cracking',
  'thinly',
  'laudable',
  'scruffy',
  'eyed',
  'prone',
  'everyday',
  'stoutly',
  'general',
  'angry',
  'devilish',
  'lovely',
  'laconic',
  'selfish',
  'gladly',
  'flexible',
  'closed',
  'elated',
  'trivial',
  'utter',
  'apparent',
  'bitter',
  'ultimate',
  'stricter',
  'slowest',
  'largest',
  'unbound',
  'upstream',
  'gently',
  'visceral',
  'dominant',
  'sheared',
  'prepared',
  'insecure',
  'shadowy',
  'adult',
  'animated',
  'happier',
  'promptly',
  'jewish',
  'fitting',
  'cheapest',
  'suddenly',
  'meager',
  'massive',
  'labored',
  'simplest',
  'earthly',
  'smallest',
  'edged',
  'glorious',
  'politely',
  'buoyant',
  'fated',
  'crossly',
  'alert',
  'fanatic',
  'rounded',
  'eloquent',
  'lapsed',
  'downcast',
  'stunning',
  'neural',
  'fired',
  'medieval',
  'raucous',
  'useful',
  'gullible',
  'reckless',
  'blank',
  'vocal',
  'cheeked',
  'enough',
  'careless',
  'social',
  'pushing',
  'generic',
  'coarse',
  'modern',
  'pathetic',
  'adrift',
  'acid',
  'short',
  'ample',
  'boxy',
  'utmost',
  'pseudo',
  'unlike',
  'genuine',
  'unborn',
  'firmly',
  'shallow',
  'shameful',
  'nameless',
  'greener',
  'agile',
  'fresher',
  'harmless',
  'hearted',
  'junior',
  'bodily',
  'favored',
  'stormy',
  'vehement',
  'wondrous',
  'mindful',
  'weighted',
  'tidy',
  'tasty',
  'shiny',
  'annoying',
  'suitably',
  'alien',
  'wicked',
  'redbrick',
  'poorer',
  'savory',
  'distant',
  'rueful',
  'stately',
  'manifest',
  'rusty',
  'exterior',
  'contrite',
  'loyal',
  'streaked',
  'false',
  'rare',
  'ethical',
  'inferior',
  'expertly',
  'periodic',
  'lightest',
  'rattling',
  'typical',
  'tersely',
  'safe',
  'newest',
  'youthful',
  'feral',
  'abusive',
  'harshly',
  'weighty',
  'latest',
  'oldest',
  'pointed',
  'noted',
  'sparing',
  'hypnotic',
  'eastward',
  'searing',
  'highest',
  'stinking',
  'peaceful',
  'thicker',
  'blacker',
  'immune',
  'spent',
  'sadly',
  'heated',
  'fleshy',
  'darkest',
  'allied',
  'brown',
  'dashed',
  'mutual',
  'hoarse',
  'sunny',
  'greenish',
  'strict',
  'derelict',
  'homesick',
  'booming',
  'softly',
  'cranky',
  'magical',
  'circular',
  'nearby',
  'swifter',
  'stupid',
  'informed',
  'meaty',
  'severe',
  'sulky',
  'silvery',
  'tepid',
  'ashy',
  'greasy',
  'blindly',
  'piano',
  'sudden',
  'aerial',
  'blankly',
  'tortuous',
  'before',
  'decisive',
  'trying',
  'loudest',
  'guarded',
  'astute',
  'unformed',
  'unjustly',
  'rightful',
  'deaf',
  'abstract',
  'major',
  'gentler',
  'disabled',
  'primary',
  'covert',
  'absent',
  'testily',
  'high',
  'terribly',
  'quaint',
  'idly',
  'first',
  'thin',
  'fearful',
  'unveiled',
  'feebly',
  'reddish',
  'fugitive',
  'clearer' ]

def writelist(li):
    """
    Write out a list to a file named x.
    """
    with open("x", "w") as fd:
        print("[", file=fd)
        dd = sorted(li)
        for i in range(len(dd)):
            if i < len(dd)-1:
                print("  '",dd[i],"',",sep='',file=fd)
            else:
                print("  '",dd[i],"'",sep='',file=fd)
        print(']',file=fd)

def checkverb(li):
    """
    Check for verbs that differ only by ending
    """
    d = set()
    for elem in li:
        d.add(elem)
    d2 = set()
    for elem in li:
        if elem+"ed" in d or elem+"d" in d or (elem[-1] == 's' and elem[:-1]+"ed" in d):
            print("remove:",elem)
            d2.add(elem)
    if len(d2) > 0:
        li2 = []
        for elem in li:
            if elem not in d2:
                li2 += [elem]
        writelist(li2)
        raise Exception()

checkverb(verbs)

def check(li):
    """
    Check a list for duplicates
    """
    d = set()
    dup = False
    for elem in li:
        if elem in d:
            dup = True
        d.add(elem)
    if dup:
        writelist(list(d))
        raise Exception()

check(verbs)
check(nouns)
check(adjs)

mset = set()
for k in verbs + adjs:
    mset.add(k)
modifiers = list(mset)
words = nouns + modifiers
puncts = ['/','=','@',',','-',':']

from random import randint
from math import log2
import sys

def randlist(li):
    """
    Return a random element from a list.
    """
    i = randint(0,len(li)-1)
    return li[i]

max_rand = 999

def firstup(s):
    """
    Make the first character of s upper case
    and the rest of the characters lower case.
    """
    return s[0:1].upper()+s[1:].lower()

def randpass(s='MNDP'):
    """
    Cenerate a password described by s, where s is a string describing 
    the password. 'N' is a noun, 'V' is a verb, 'A' is an
    adjective, 'M' is a modifier (verb or adjective), 'D' is
    a digit, and 'P' is punctuation.
    """
    v = ''
    for c in s:
        if c == 'N':
            v += firstup(randlist(nouns))
        elif c == 'V':
            v += firstup(randlist(verbs))
        elif c == 'D':
            v += str(randint(0,9))
        elif c == 'M':
            v += firstup(randlist(modifiers))
        elif c == 'P':
            v += randlist(puncts)
        elif c == 'A':
            v += firstup(randlist(adjs))
        elif c == 'W':
            v += firstup(randlist(words))
        else:
            raise Exception(c)
    return v

def entropy(s='MNDP'):
    """
    Calculate the entropy, that is, the number of possible
    passwords generated by s, where s is a string describing 
    the password. 'N' is a noun, 'V' is a verb, 'A' is an
    adjective, 'M' is a modifier (verb or adjective), 'D' is
    a digit, and 'P' is punctuation.
    """
    e = 1
    for c in s:
        if c == 'N':
            e *= len(nouns)
        elif c == 'V':
            e *= len(verbs)
        elif c == 'D':
            e *= 10
        elif c == 'M':
            e *= len(modifiers)
        elif c == 'P':
            e *= len(puncts)
        elif c == 'A':
            e *= len(adjs)
        elif c == 'W':
            e *= len(words)
        else:
            raise Exception(c)
    return e

mins = 60
hours = 60*mins
days = 24*hours
years = 365*days

def safety(e,secs_per_attempt):
    """
    Calculates and prints the amount of time
    to try 1% of the passwords, assuming the
    attacker knows the algorithm for generating
    them, and the secs_per_attempt is set to
    the minimum number of seconds per attempt.
    """
    secs = e*secs_per_attempt/100
    if secs >= years:
        print("%.2f years" % (secs/years))
    elif secs >= days:
        print("%.2f days" % (secs/days))
    elif secs >= hours:
        print("%.2f hours" % (secs/hours))
    elif secs >= mins:
        print("%.2f minutes" % (secs/mins))
    else:
        print("%d seconds" % secs)

import argparse
import os

def main():
    parser = argparse.ArgumentParser(description='''
Generate a password described by "formula", where "formula" is a string describing the password:
'N' is a noun,
'V' is a verb,
'A' is an adjective,
'M' is a modifier (verb or adjective),
'D' is a digit,
'W' is a word,
'P' is punctuation.

This code was inspired by the comic https://xkcd.com/936/. Because of this, the
default formula is WWWW.
    '''.strip())
    parser.add_argument('--num', '-n', dest='num', type=int, default=1, help='Number of passwords to generate')
    parser.add_argument('--ofile', '-o', dest='ofile', type=str, help='Output file')
    parser.add_argument('--secs', '-s', dest='secs', type=float, default=1, help='Seconds per guess')
    parser.add_argument('formula', metavar='formula', type=str, default='WWWW', nargs='?', help='Password formula(s)')
    args = parser.parse_args()
    sec_per_guess = args.secs
    if args.ofile is not None and os.path.exists(args.ofile):
        os.remove(args.ofile)
    formula = args.formula
    print('formula:',formula)
    e = entropy(formula)
    print("%.2f bits of entropy" % log2(e))
    print("Time to guess 1% of all passwords: ",end='')
    safety(e,sec_per_guess)
    print("Seconds per guess:",sec_per_guess)
    if args.ofile is not None:
        with open(args.ofile,"a") as fd:
            for n in range(args.num):
                passw = randpass(formula)
                print(passw,file=fd)
    else:
        for n in range(args.num):
            passw = randpass(formula)
            print("pass:",passw)

if __name__ == "__main__":
    main()
